#ifdef HAVE_LIBNX
MSG_HASH(
   MENU_ENUM_LABEL_SWITCH_CPU_PROFILE,
   "switch_cpu_profile"
   )
#endif

MSG_HASH(
   MENU_ENUM_LABEL_ACCOUNTS_CHEEVOS_USERNAME,
   "accounts_cheevos_username"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ACCOUNTS_LIST,
   "accounts_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ACCOUNTS_RETRO_ACHIEVEMENTS,
   "retro_achievements"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ACHIEVEMENT_PAUSE_MENU,
   "achievement_pause_menu"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ACHIEVEMENT_PAUSE_CANCEL,
   "achievement_pause_cancel"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ACHIEVEMENT_RESUME_CANCEL,
   "achievement_resume_cancel"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ACHIEVEMENT_PAUSE,
   "achievement_pause"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ACHIEVEMENT_RESUME,
   "achievement_resume"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ACCOUNTS_TWITCH,
   "twitch"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ACCOUNTS_YOUTUBE,
   "youtube"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ACCOUNTS_FACEBOOK,
   "facebook"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ACHIEVEMENT_LIST,
   "achievement_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ACHIEVEMENT_LIST_HARDCORE,
   "achievement_list_hardcore"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ADD_CONTENT_LIST,
   "add_content"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONFIGURATIONS_LIST,
   "configurations_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_EXPLORE_TAB,
   "explore_tab"
   )
MSG_HASH(
   MENU_ENUM_LABEL_EXPLORE_ITEM,
   "explore_item"
   )
MSG_HASH(
   MENU_ENUM_LABEL_EXPLORE_INITIALISING_LIST,
   "explore_initialising_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENTLESS_CORES_TAB,
   "contentless_cores_tab"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENTLESS_CORE,
   "contentless_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ADD_TAB,
   "add_tab"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_TAB,
   "netplay_tab"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ASSETS_DIRECTORY,
   "assets_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_BLOCK_FRAMES,
   "audio_block_frames"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DEVICE,
   "audio_device"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER,
   "audio_driver"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_RSOUND,
   "rsound"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_AUDIOIO,
   "audioio"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_OSS,
   "oss"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_ALSA,
   "alsa"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_ALSATHREAD,
   "alsathread"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_TINYALSA,
   "tinyalsa"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_ROAR,
   "roar"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_COREAUDIO,
   "coreaudio"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_COREAUDIO3,
   "coreaudio3"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_AL,
   "openal"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_SL,
   "opensl"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_SDL,
   "sdl"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_SDL2,
   "sdl2"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_DSOUND,
   "dsound"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_WASAPI,
   "wasapi"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_XAUDIO,
   "xaudio"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_PULSE,
   "pulse"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_PIPEWIRE,
   "pipewire"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_EXT,
   "ext"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_XENON360,
   "xenon360"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_PS3,
   "ps3"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_WII,
   "gx"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_WIIU,
   "AX"
   )
#if defined(VITA)
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_PSP,
   "vita"
   )
#elif defined(ORBIS)
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_PSP,
   "orbis"
   )
#else
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_PSP,
   "psp"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_PS2,
   "ps2"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_CTR,
   "dsp"
   )
#if defined(HAVE_LIBNX)
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_SWITCH,
   "switch_audren_thread"
   )
#else
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_SWITCH,
   "switch"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_RWEBAUDIO,
   "rwebaudio"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_AUDIOWORKLET,
   "audioworklet"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_JACK,
   "jack"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DRIVER_NULL,
   "null"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DSP_PLUGIN,
   "audio_dsp_plugin"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_DSP_PLUGIN_REMOVE,
   "audio_dsp_plugin_remove"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_ENABLE,
   "audio_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_FILTER_DIR,
   "audio_filter_dir"
   )
MSG_HASH(
   MENU_ENUM_LABEL_TURBO_DEADZONE_LIST,
   "turbo_deadzone_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_LATENCY,
   "audio_latency"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_MAX_TIMING_SKEW,
   "audio_max_timing_skew"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_MUTE,
   "audio_mute_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_RESPECT_SILENT_MODE,
   "audio_respect_silent_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_FASTFORWARD_MUTE,
   "audio_fastforward_mute"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_FASTFORWARD_SPEEDUP,
   "audio_fastforward_speedup"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_OUTPUT_RATE,
   "audio_output_rate"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_RATE_CONTROL_DELTA,
   "audio_rate_control_delta"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_RESAMPLER_DRIVER,
   "audio_resampler_driver"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_SETTINGS,
   "audio_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_RESAMPLER_SETTINGS,
   "audio_resampler_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_SYNCHRONIZATION_SETTINGS,
   "audio_synchronization_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_OUTPUT_SETTINGS,
   "audio_output_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_SYNC,
   "audio_sync"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_VOLUME,
   "audio_volume"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_WASAPI_EXCLUSIVE_MODE,
   "audio_wasapi_exclusive_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_WASAPI_FLOAT_FORMAT,
   "audio_wasapi_float_format"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_WASAPI_SH_BUFFER_LENGTH,
   "audio_wasapi_sh_buffer_length"
   )
#ifdef HAVE_MICROPHONE
MSG_HASH(
   MENU_ENUM_LABEL_MICROPHONE_ENABLE,
   "microphone_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MICROPHONE_RESAMPLER_DRIVER,
   "microphone_resampler_driver"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MICROPHONE_DEVICE,
   "microphone_device"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MICROPHONE_SETTINGS,
   "microphone_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MICROPHONE_DRIVER,
   "microphone_driver"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MICROPHONE_INPUT_RATE,
   "microphone_input_rate"
)
MSG_HASH(
   MENU_ENUM_LABEL_MICROPHONE_LATENCY,
   "microphone_latency"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MICROPHONE_BLOCK_FRAMES,
   "microphone_block_frames"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MICROPHONE_WASAPI_EXCLUSIVE_MODE,
   "microphone_wasapi_exclusive_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MICROPHONE_WASAPI_FLOAT_FORMAT,
   "microphone_wasapi_float_format"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MICROPHONE_WASAPI_SH_BUFFER_LENGTH,
   "microphone_wasapi_sh_buffer_length"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MICROPHONE_RESAMPLER_QUALITY,
   "microphone_resampler_quality"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_AUTOSAVE_INTERVAL,
   "autosave_interval"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REPLAY_CHECKPOINT_INTERVAL,
   "replay_checkpoint_interval"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REPLAY_CHECKPOINT_DESERIALIZE,
   "replay_checkpoint_deserialize"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUTO_OVERRIDES_ENABLE,
   "auto_overrides_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUTO_REMAPS_ENABLE,
   "auto_remaps_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INITIAL_DISK_CHANGE_ENABLE,
   "initial_disk_change_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_GLOBAL_CORE_OPTIONS,
   "global_core_options"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUTO_SHADERS_ENABLE,
   "auto_shaders_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_BLOCK_SRAM_OVERWRITE,
   "block_sram_overwrite"
   )
#ifdef HAVE_LAKKA
MSG_HASH(
   MENU_ENUM_LABEL_BLUETOOTH_ENABLE,
   "bluetooth_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_TIMEZONE,
   "timezone"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_BUILDBOT_ASSETS_URL,
   "buildbot_assets_url"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CACHE_DIRECTORY,
   "cache_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CAMERA_ALLOW,
   "camera_allow"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DISCORD_ALLOW,
   "discord_allow"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CAMERA_DRIVER,
   "camera_driver"
   )
MSG_HASH(
   MENU_ENUM_LABEL_BLUETOOTH_DRIVER,
   "bluetooth_driver"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CB_CORE_CONTENT_DIRS_LIST,
   "cb_core_content_dirs_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CB_CORE_CONTENT_DOWNLOAD,
   "cb_core_content_download"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CB_CORE_CONTENT_LIST,
   "cb_core_content_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CB_CORE_SYSTEM_FILES_DOWNLOAD,
   "cb_core_system_files_download"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CB_CORE_SYSTEM_FILES_LIST,
   "cb_core_system_files_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CB_CORE_THUMBNAILS_DOWNLOAD,
   "cb_core_thumbnails_download"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CB_CORE_UPDATER_DOWNLOAD,
   "cb_core_updater_download"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CB_CORE_UPDATER_LIST,
   "cb_core_updater_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CB_DOWNLOAD_URL,
   "cb_download_url"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CB_LAKKA_DOWNLOAD,
   "cb_lakka_download"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CB_LAKKA_LIST,
   "cb_lakka_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CB_MENU_THUMBNAIL,
   "cb_menu_thumbnail"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CB_MENU_WALLPAPER,
   "cb_menu_wallpaper"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CB_UPDATE_ASSETS,
   "cb_update_assets"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CB_UPDATE_AUTOCONFIG_PROFILES,
   "cb_update_autoconfig_profiles"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CB_UPDATE_CHEATS,
   "cb_update_cheats"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CB_UPDATE_CORE_INFO_FILES,
   "cb_update_core_info_files"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CB_UPDATE_DATABASES,
   "cb_update_databases"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CB_UPDATE_OVERLAYS,
   "cb_update_overlays"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CB_UPDATE_SHADERS_CG,
   "cb_update_shaders_cg"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CB_UPDATE_SHADERS_GLSL,
   "cb_update_shaders_glsl"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_APPLY_CHANGES,
   "cheat_apply_changes"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_DATABASE_PATH,
   "cheat_database_path"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_FILE_LOAD,
   "cheat_file_load"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_FILE_LOAD_APPEND,
   "cheat_file_load_append"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_FILE_SAVE_AS,
   "cheat_file_save_as"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_NUM_PASSES,
   "cheat_num_passes"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_DESCRIPTION,
   "cheevos_description"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_ENABLE,
   "cheevos_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_HARDCORE_MODE_ENABLE,
   "cheevos_hardcore_mode_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_RICHPRESENCE_ENABLE,
   "cheevos_richpresence_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_BADGES_ENABLE,
   "cheevos_badges_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_LOCKED_ENTRY,
   "cheevos_locked_entry"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_PASSWORD,
   "cheevos_password"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_TEST_UNOFFICIAL,
   "cheevos_test_unofficial"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_UNLOCKED_ENTRY,
   "cheevos_unlocked_entry"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_UNLOCKED_ENTRY_HARDCORE,
   "cheevos_unlocked_entry_hardcore"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_USERNAME,
   "cheevos_username"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_UNLOCK_SOUND_ENABLE,
   "cheevos_unlock_sound_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_VERBOSE_ENABLE,
   "cheevos_verbose_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_AUTO_SCREENSHOT,
   "cheevos_auto_screenshot"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_START_ACTIVE,
   "cheevos_start_active"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_CHALLENGE_INDICATORS,
   "cheevos_challenge_indicators"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_APPEARANCE_SETTINGS,
   "cheevos_appearance_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_APPEARANCE_ANCHOR,
   "cheevos_appearance_anchor"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_APPEARANCE_PADDING_AUTO,
   "cheevos_appearance_padding_auto"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_VISIBILITY_SETTINGS,
   "cheevos_visibility_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_VISIBILITY_SUMMARY,
   "cheevos_visibility_summary"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_VISIBILITY_UNLOCK,
   "cheevos_visibility_unlock"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_VISIBILITY_MASTERY,
   "cheevos_visibility_mastery"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_VISIBILITY_ACCOUNT,
   "cheevos_visibility_account"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_VISIBILITY_LBOARD_START,
   "cheevos_visibility_lboard_start"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_VISIBILITY_LBOARD_SUBMIT,
   "cheevos_visibility_lboard_submit"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_VISIBILITY_LBOARD_CANCEL,
   "cheevos_visibility_lboard_cancel"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_VISIBILITY_LBOARD_TRACKERS,
   "cheevos_visibility_lboard_trackers"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEEVOS_VISIBILITY_PROGRESS_TRACKER,
   "cheevos_visibility_progress_tracker"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CLOSE_CONTENT,
   "close_content"
   )
MSG_HASH(
   MENU_ENUM_LABEL_COLLECTION,
   "collection"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONFIGURATIONS,
   "configurations"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONFIGURATION_SETTINGS,
   "configuration_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONFIG_SAVE_ON_EXIT,
   "config_save_on_exit"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REMAP_SAVE_ON_EXIT,
   "remap_save_on_exit"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONNECT_WIFI,
   "connect_wifi"
   )
MSG_HASH(
   MENU_ENUM_LABEL_WIFI_DISCONNECT,
   "disconnect_wifi"
   )
MSG_HASH(
   MENU_ENUM_LABEL_WIFI_NETWORKS,
   "wifi_list_networks"
   )
MSG_HASH(
   MENU_ENUM_LABEL_WIFI_ENABLED,
   "wifi_enabled"
   )
MSG_HASH(
   MENU_ENUM_LABEL_WIFI_NETWORK_SCAN,
   "wifi_network_scan"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONNECT_NETPLAY_ROOM,
   "connect_room"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_ACTIONS,
   "content_actions"
   )
MSG_HASH(
   MENU_ENUM_LABEL_BROWSE_URL_LIST,
   "browse_url_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_DATABASE_DIRECTORY,
   "content_database_path"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_HISTORY_SIZE,
   "content_history_size"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_FAVORITES_SIZE,
   "content_favorites_size"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_ENTRY_REMOVE,
   "playlist_entry_remove_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_SETTINGS,
   "quick_menu"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_ASSETS_DIRECTORY,
   "core_assets_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_CHEAT_OPTIONS,
   "core_cheat_options"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_COUNTERS,
   "core_counters"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_ENABLE,
   "menu_core_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_INFORMATION,
   "core_information"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_CREATE_BACKUP,
   "core_create_backup"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_RESTORE_BACKUP_LIST,
   "core_restore_backup_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CORE_RESTORE_BACKUP_LIST,
   "deferred_core_restore_backup_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_DELETE_BACKUP_LIST,
   "core_delete_backup_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CORE_DELETE_BACKUP_LIST,
   "deferred_core_delete_backup_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DISC_INFORMATION,
   "disc_information"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_INFO_ENTRY,
   "core_info_entry"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_INPUT_REMAPPING_OPTIONS,
   "core_input_remapping_options"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_SPLIT_JOYCON,
   "input_split_joycon"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_LIST,
   "load_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_LIST_UNLOAD,
   "unload_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SIDELOAD_CORE_LIST,
   "sideload_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SAVESTATE_LIST,
   "savestate_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_OPTIONS,
   "core_options"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_OPTION_ENTRY,
   "core_option_entry"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_SETTINGS,
   "core_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_SET_SUPPORTS_NO_CONTENT_ENABLE,
   "core_set_supports_no_content_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_UPDATER_AUTO_EXTRACT_ARCHIVE,
   "core_updater_auto_extract_archive"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_UPDATER_SHOW_EXPERIMENTAL_CORES,
   "core_updater_show_experimental_cores"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_UPDATER_AUTO_BACKUP,
   "core_updater_auto_backup"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_UPDATER_AUTO_BACKUP_HISTORY_SIZE,
   "core_updater_auto_backup_history_size"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_UPDATER_BUILDBOT_URL,
   "core_updater_buildbot_url"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_UPDATER_LIST,
   "core_updater_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_MANAGER_LIST,
   "core_manager_list"
   )
#ifdef HAVE_MIST
MSG_HASH(
   MENU_ENUM_LABEL_CORE_STEAM_INSTALL,
   "core_steam_install"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_STEAM_UNINSTALL,
   "core_steam_uninstall"
   )
MSG_HASH(
   MENU_ENUM_LABEL_STEAM_SETTINGS,
   "steam_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_STEAM_RICH_PRESENCE_ENABLE,
   "steam_rich_presence_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_STEAM_RICH_PRESENCE_FORMAT,
   "steam_rich_presence_format"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_CPU_ARCHITECTURE,
   "system_information_cpu_architecture"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CPU_CORES,
   "system_information_cpu_cores"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CURSOR_MANAGER,
   "cursor_manager"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CURSOR_MANAGER_LIST,
   "cursor_manager_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CUSTOM_BIND,
   "custom_bind"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CUSTOM_BIND_ALL,
   "custom_bind_all"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DATABASE_MANAGER,
   "database_manager"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DATABASE_MANAGER_LIST,
   "database_manager_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_FRAME_TIME_COUNTER_SETTINGS_LIST,
   "deferred_frame_time_counter_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_VIDEO_SHADER_PRESET_MANAGER_LIST,
   "deferred_video_shader_preset_manager_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CDROM_INFO_LIST,
   "deferred_cdrom_info_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CDROM_INFO_DETAIL_LIST,
   "deferred_cdrom_info_detail_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_REMAPPINGS_PORT_LIST,
   "deferred_remappings_port_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST,
   "deferred_dropdown_box_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_SPECIAL,
   "deferred_dropdown_box_list_special"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_RESOLUTION,
   "deferred_dropdown_box_list_resolution"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_VIDEO_SHADER_PARAMETER,
   "deferred_dropdown_box_list_video_shader_parameter"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_VIDEO_SHADER_PRESET_PARAMETER,
   "deferred_dropdown_box_list_video_shader_preset_parameter"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_VIDEO_SHADER_NUM_PASSES,
   "deferred_dropdown_box_list_video_shader_num_passes"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_PLAYLIST_DEFAULT_CORE,
   "deferred_dropdown_box_list_playlist_default_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_PLAYLIST_LABEL_DISPLAY_MODE,
   "deferred_dropdown_box_list_playlist_label_display_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_PLAYLIST_RIGHT_THUMBNAIL_MODE,
   "deferred_dropdown_box_list_playlist_right_thumbnail_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_PLAYLIST_LEFT_THUMBNAIL_MODE,
   "deferred_dropdown_box_list_playlist_left_thumbnail_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_PLAYLIST_SORT_MODE,
   "deferred_dropdown_box_list_playlist_sort_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_DISK_INDEX,
   "deferred_dropdown_box_list_disk_index"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_INPUT_RETROPAD_BIND,
   "deferred_dropdown_box_list_input_retropad_bind"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_INPUT_DEVICE_TYPE,
   "deferred_dropdown_box_list_input_device_type"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_INPUT_SELECT_RESERVED_DEVICE,
   "deferred_dropdown_box_list_input_select_reserved_device"
   )
#ifdef ANDROID
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_INPUT_SELECT_PHYSICAL_KEYBOARD,
   "deferred_dropdown_box_list_input_select_physical_keyboard"
)
#endif
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_INPUT_DESCRIPTION,
   "deferred_dropdown_box_list_input_description"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_INPUT_DESCRIPTION_KBD,
   "deferred_dropdown_box_list_input_description_kbd"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_NETPLAY_MITM_SERVER,
   "deferred_dropdown_box_list_netplay_mitm_server"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_AUDIO_DEVICE,
   "deferred_dropdown_box_list_audio_device"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_MIDI_DEVICE,
   "deferred_dropdown_box_list_midi_device"
   )
#ifdef HAVE_MICROPHONE
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_MICROPHONE_DEVICE,
   "deferred_dropdown_box_list_microphone_device"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_MICROPHONE_SETTINGS_LIST,
   "deferred_microphone_settings_list"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CONFIGURATIONS_LIST,
   "deferred_configurations_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_PLAYLIST_LIST,
   "deferred_playlist_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_FAVORITES_LIST,
   "deferred_favorites_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_IMAGES_LIST,
   "deferred_images_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_MUSIC_LIST,
   "deferred_music_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_VIDEO_LIST,
   "deferred_video_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_EXPLORE_LIST,
   "deferred_explore_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CONTENTLESS_CORES_LIST,
   "deferred_contentless_cores_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_NETPLAY,
   "deferred_netplay"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_MUSIC,
   "deferred_music"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_BROWSE_URL_START,
   "deferred_browse_url_start"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_BROWSE_URL_LIST,
   "deferred_browse_url_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_ACCOUNTS_CHEEVOS_LIST,
   "deferred_accounts_cheevos_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_ACCOUNTS_TWITCH_LIST,
   "deferred_accounts_twitch_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_ACCOUNTS_YOUTUBE_LIST,
   "deferred_accounts_youtube_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_ACCOUNTS_FACEBOOK_LIST,
   "deferred_accounts_facebook_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_ACCOUNTS_LIST,
   "deferred_accounts_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_ARCHIVE_ACTION,
   "deferred_archive_action"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_ARCHIVE_ACTION_DETECT_CORE,
   "deferred_archive_action_detect_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_ARCHIVE_OPEN,
   "deferred_archive_open"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_ARCHIVE_OPEN_DETECT_CORE,
   "deferred_archive_open_detect_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_AUDIO_SETTINGS_LIST,
   "deferred_audio_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_AUDIO_RESAMPLER_SETTINGS_LIST,
   "deferred_audio_resampler_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_AUDIO_MIXER_SETTINGS_LIST,
   "deferred_audio_mixer_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_MENU_SOUNDS_LIST,
   "deferred_menu_sounds_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CONFIGURATION_SETTINGS_LIST,
   "deferred_configuration_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CORE_CONTENT_DIRS_LIST,
   "deferred_core_content_dirs_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CORE_CONTENT_DIRS_SUBDIR_LIST,
   "deferred_core_content_dirs_subdir_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CORE_CONTENT_LIST,
   "deferred_core_content_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CORE_SYSTEM_FILES_LIST,
   "deferred_core_system_files_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CORE_LIST,
   "deferred_core_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CORE_LIST_SET,
   "deferred_core_list_set"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CORE_SETTINGS_LIST,
   "deferred_core_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CORE_INFORMATION_LIST,
   "deferred_core_information_list"
   )
#ifdef HAVE_MIST
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CORE_INFORMATION_STEAM_LIST,
   "deferred_core_information_steam_list"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CORE_UPDATER_LIST,
   "core_updater"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CORE_MANAGER_LIST,
   "deferred_core_manager_list"
   )
#ifdef HAVE_MIST
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_STEAM_SETTINGS_LIST,
   "deferred_steam_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CORE_MANAGER_STEAM_LIST,
   "deferred_core_manager_steam_list"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CURSOR_MANAGER_LIST,
   "deferred_cursor_manager_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DATABASE_MANAGER_LIST,
   "deferred_database_manager_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DIRECTORY_SETTINGS_LIST,
   "deferred_directory_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DRIVER_SETTINGS_LIST,
   "deferred_driver_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_FRAME_THROTTLE_SETTINGS_LIST,
   "deferred_frame_throttle_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_INPUT_RETROPAD_BINDS_LIST,
   "deferred_input_retropad_binds"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_INPUT_HOTKEY_BINDS_LIST,
   "deferred_input_hotkey_binds"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_INPUT_SETTINGS_LIST,
   "deferred_input_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_INPUT_TURBO_FIRE_SETTINGS_LIST,
   "deferred_input_turbo_fire_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_INPUT_HAPTIC_FEEDBACK_SETTINGS_LIST,
   "deferred_input_haptic_feedback_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_INPUT_MENU_SETTINGS_LIST,
   "deferred_input_menu_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_LATENCY_SETTINGS_LIST,
   "deferred_latency_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_AI_SERVICE_SETTINGS_LIST,
   "deferred_ai_service_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_ACCESSIBILITY_SETTINGS_LIST,
   "deferred_accessibility_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_POWER_MANAGEMENT_SETTINGS_LIST,
   "deferred_power_management_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CPU_PERFPOWER_LIST,
   "deferred_cpu_perfpower_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CPU_POLICY_ENTRY,
   "deferred_cpu_policy_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_LAKKA_LIST,
   "deferred_lakka_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_LAKKA_SERVICES_LIST,
   "deferred_lakka_services_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_LOGGING_SETTINGS_LIST,
   "deferred_logging_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_MENU_FILE_BROWSER_SETTINGS_LIST,
   "deferred_menu_file_browser_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_MENU_SETTINGS_LIST,
   "deferred_menu_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_APPICON_SETTINGS,
   "appicon_settings"
   )
#ifdef _3DS
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_MENU_BOTTOM_SETTINGS_LIST,
   "deferred_menu_bottom_settings"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_MENU_VIEWS_SETTINGS_LIST,
   "deferred_menu_views_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_QUICK_MENU_VIEWS_SETTINGS_LIST,
   "deferred_quick_menu_views_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_SETTINGS_VIEWS_SETTINGS_LIST,
   "deferred_settings_views_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_SUBSYSTEM_SETTINGS_LIST,
   "deferred_subsystem_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_NETWORK_HOSTING_SETTINGS_LIST,
   "deferred_network_hosting_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_NETWORK_SETTINGS_LIST,
   "deferred_network_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_NETPLAY_KICK_LIST,
   "deferred_netplay_kick_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_NETPLAY_BAN_LIST,
   "deferred_netplay_ban_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_NETPLAY_LOBBY_FILTERS_LIST,
   "deferred_netplay_lobby_filters_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_ONSCREEN_DISPLAY_SETTINGS_LIST,
   "deferred_onscreen_display_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_ONSCREEN_OVERLAY_SETTINGS_LIST,
   "deferred_onscreen_overlay_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_OSK_OVERLAY_SETTINGS_LIST,
   "deferred_osk_overlay_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_OVERLAY_LIGHTGUN_SETTINGS_LIST,
   "deferred_overlay_lightgun_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_OVERLAY_MOUSE_SETTINGS_LIST,
   "deferred_overlay_mouse_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_ONSCREEN_VIDEO_LAYOUT_SETTINGS_LIST,
   "deferred_onscreen_video_layout_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_ONSCREEN_NOTIFICATIONS_SETTINGS_LIST,
   "deferred_onscreen_notifications_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_ONSCREEN_NOTIFICATIONS_VIEWS_SETTINGS_LIST,
   "deferred_onscreen_notifications_views_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_PLAYLIST_SETTINGS_LIST,
   "deferred_playlist_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_PLAYLIST_MANAGER_LIST,
   "deferred_playlist_manager_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_PLAYLIST_MANAGER_SETTINGS,
   "deferred_playlist_manager_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_PRIVACY_SETTINGS_LIST,
   "deferred_privacy_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_MIDI_SETTINGS_LIST,
   "deferred_midi_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_RDB_ENTRY_DETAIL,
   "deferred_rdb_entry_detail"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_RECORDING_SETTINGS_LIST,
   "deferred_recording_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_RETRO_ACHIEVEMENTS_SETTINGS_LIST,
   "deferred_retro_achievements_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CHEEVOS_APPEARANCE_SETTINGS_LIST,
   "deferred_cheevos_appearance_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CHEEVOS_VISIBILITY_SETTINGS_LIST,
   "deferred_cheevos_visibility_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_REWIND_SETTINGS_LIST,
   "deferred_rewind_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CHEAT_DETAILS_SETTINGS_LIST,
   "deferred_cheat_details_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CHEAT_SEARCH_SETTINGS_LIST,
   "deferred_cheat_search_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_SAVING_SETTINGS_LIST,
   "deferred_saving_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CLOUD_SYNC_SETTINGS_LIST,
   "deferred_cloud_sync_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_PL_THUMBNAILS_UPDATER_LIST,
   "deferred_pl_thumbnails_updater_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_UPDATER_SETTINGS_LIST,
   "deferred_updater_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_USER_BINDS_LIST,
   "deferred_user_binds_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_USER_INTERFACE_SETTINGS_LIST,
   "deferred_user_interface_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_USER_SETTINGS_LIST,
   "deferred_user_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_VIDEO_FILTER,
   "deferred_video_filter"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_VIDEO_SETTINGS_LIST,
   "deferred_video_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_VIDEO_WINDOWED_MODE_SETTINGS_LIST,
   "deferred_video_windowed_mode_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_VIDEO_FULLSCREEN_MODE_SETTINGS_LIST,
   "deferred_video_fullscreen_mode_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_VIDEO_OUTPUT_SETTINGS_LIST,
   "deferred_video_output_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_VIDEO_SCALING_SETTINGS_LIST,
   "deferred_video_scaling_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_VIDEO_HDR_SETTINGS_LIST,
   "deferred_video_hdr_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_VIDEO_SYNCHRONIZATION_SETTINGS_LIST,
   "deferred_video_synchronization_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CRT_SWITCHRES_SETTINGS_LIST,
   "deferred_crt_switchres_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_BLUETOOTH_SETTINGS_LIST,
   "deferred_bluetooth_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_WIFI_SETTINGS_LIST,
   "deferred_wifi_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_WIFI_NETWORKS_LIST,
   "deferred_wifi_networks_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_INFORMATION,
   "deferred_information"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DELETE_ENTRY,
   "delete_entry"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FAVORITES,
   "favorites"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DIRECTORY_SETTINGS,
   "directory_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DISK_TRAY_EJECT,
   "disk_tray_eject"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DISK_TRAY_INSERT,
   "disk_tray_insert"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DISK_IMAGE_APPEND,
   "disk_image_append"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SUBSYSTEM_ADD,
   "subsystem_add"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SUBSYSTEM_LOAD,
   "subsystem_load"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DISK_OPTIONS,
   "core_disk_options"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DISK_INDEX,
   "core_disk_index"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DOWNLOADED_FILE_DETECT_CORE_LIST,
   "downloaded_file_detect_core_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DOWNLOAD_CORE_CONTENT,
   "download_core_content"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DOWNLOAD_CORE_CONTENT_DIRS,
   "download_core_content_dirs"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DOWNLOAD_CORE_SYSTEM_FILES,
   "download_core_system_files"
   )
MSG_HASH(
   MENU_ENUM_LABEL_UPDATE_INSTALLED_CORES,
   "update_installed_cores"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SWITCH_INSTALLED_CORES_PFD,
   "switch_installed_cores_pfd"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_DIR,
   "content_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SCALE_FACTOR,
   "menu_scale_factor"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_WIDGET_SCALE_AUTO,
   "menu_widget_scale_auto"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_WIDGET_SCALE_FACTOR,
   "menu_widget_scale_factor"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_WIDGET_SCALE_FACTOR_WINDOWED,
   "menu_widget_scale_factor_windowed"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DRIVER_SETTINGS,
   "driver_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHECK_FOR_MISSING_FIRMWARE,
   "check_for_missing_firmware"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_OPTION_CATEGORY_ENABLE,
   "core_option_category_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_INFO_CACHE_ENABLE,
   "core_info_cache_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_INFO_SAVESTATE_BYPASS,
   "core_info_savestate_bypass"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DUMMY_ON_CORE_SHUTDOWN,
   "dummy_on_core_shutdown"
   )
#ifndef HAVE_DYNAMIC
MSG_HASH(
   MENU_ENUM_LABEL_ALWAYS_RELOAD_CORE_ON_RUN_CONTENT,
   "always_reload_core_on_run_content"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_DYNAMIC_WALLPAPER,
   "menu_dynamic_wallpaper_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DYNAMIC_WALLPAPERS_DIRECTORY,
   "dynamic_wallpapers_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FASTFORWARD_RATIO,
   "fastforward_ratio"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FASTFORWARD_FRAMESKIP,
   "fastforward_frameskip"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FILE_BROWSER_CORE,
   "file_browser_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FILE_BROWSER_CORE_DETECTED,
   "file_browser_core_detected"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FILE_BROWSER_CORE_SELECT_FROM_COLLECTION,
   "file_browser_core_select_from_collection"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FILE_BROWSER_CORE_SELECT_FROM_COLLECTION_CURRENT_CORE,
   "file_browser_core_select_from_collection_current_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FILE_BROWSER_DIRECTORY,
   "file_browser_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FILE_BROWSER_IMAGE,
   "file_browser_image"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FILE_BROWSER_IMAGE_OPEN_WITH_VIEWER,
   "file_browser_image_open_with_viewer"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FILE_BROWSER_MOVIE_OPEN,
   "file_browser_movie_open"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FILE_BROWSER_MUSIC_OPEN,
   "file_browser_music_open"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FILE_BROWSER_PLAIN_FILE,
   "file_browser_plain_file"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FILE_BROWSER_REMAP,
   "file_browser_remap"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FILE_BROWSER_SHADER,
   "file_browser_shader"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FILE_BROWSER_SHADER_PRESET,
   "file_browser_shader_preset"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FAVORITES_TAB,
   "favorites_tab"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FPS_SHOW,
   "fps_show"
   )
MSG_HASH(
   MENU_ENUM_LABEL_STATISTICS_SHOW,
   "statistics_show"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_PING_SHOW,
   "netplay_ping_show"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FRAME_THROTTLE_ENABLE,
   "fastforward_ratio_throttle_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FRAME_THROTTLE_SETTINGS,
   "frame_throttle_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FRONTEND_COUNTERS,
   "frontend_counters"
   )
MSG_HASH(
   MENU_ENUM_LABEL_GAME_SPECIFIC_OPTIONS,
   "game_specific_options"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_OPTION_OVERRIDE_LIST,
   "core_option_override_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CORE_OPTION_OVERRIDE_LIST,
   "deferred_core_option_override_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_GAME_SPECIFIC_CORE_OPTIONS_CREATE,
   "game_specific_core_options_create"
   )
MSG_HASH(
   MENU_ENUM_LABEL_GAME_SPECIFIC_CORE_OPTIONS_REMOVE,
   "game_specific_core_options_remove"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FOLDER_SPECIFIC_CORE_OPTIONS_CREATE,
   "folder_specific_core_options_create"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FOLDER_SPECIFIC_CORE_OPTIONS_REMOVE,
   "folder_specific_core_options_remove"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_OPTION_OVERRIDE_INFO,
   "core_option_override_info"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_OPTIONS_RESET,
   "core_options_reset"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_OPTIONS_FLUSH,
   "core_options_flush"
   )
MSG_HASH(
   MENU_ENUM_LABEL_GAME_SPECIFIC_OPTIONS_CREATE,
   "game_specific_options_create"
   )
MSG_HASH(
   MENU_ENUM_LABEL_GAME_SPECIFIC_OPTIONS_IN_USE,
   "game_specific_options_in_use"
   )
MSG_HASH(
   MENU_ENUM_LABEL_HELP,
   "help"
   )
MSG_HASH(
   MENU_ENUM_LABEL_HELP_CHEEVOS_DESCRIPTION,
   "help_cheevos_description"
   )
MSG_HASH(
   MENU_ENUM_LABEL_HELP_AUDIO_VIDEO_TROUBLESHOOTING,
   "help_audio_video_troubleshooting"
   )
MSG_HASH(
   MENU_ENUM_LABEL_HELP_CHANGE_VIRTUAL_GAMEPAD,
   "help_change_virtual_gamepad"
   )
MSG_HASH(
   MENU_ENUM_LABEL_HELP_CONTROLS,
   "help_controls"
   )
MSG_HASH(
   MENU_ENUM_LABEL_HELP_LIST,
   "help_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_HELP_LOADING_CONTENT,
   "help_loading_content"
   )
MSG_HASH(
   MENU_ENUM_LABEL_HELP_SCANNING_CONTENT,
   "help_scanning_content"
   )
MSG_HASH(
   MENU_ENUM_LABEL_HELP_WHAT_IS_A_CORE,
   "help_what_is_a_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_HISTORY_LIST_ENABLE,
   "history_list_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_HISTORY_TAB,
   "history_tab"
   )
MSG_HASH(
   MENU_ENUM_LABEL_HORIZONTAL_MENU,
   "horizontal_menu"
   )
MSG_HASH(
   MENU_ENUM_LABEL_IMAGES_TAB,
   "images_tab"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INFORMATION,
   "information"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INFORMATION_LIST,
   "information_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INFO_SCREEN,
   "info_screen"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_ALL_USERS_CONTROL_MENU,
   "all_users_control_menu"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SINGLECLICK_PLAYLISTS,
   "menu_singleclick_playlists"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_ALLOW_TABS_BACK,
   "menu_allow_tabs_back"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_INPUT_SWAP_OK_CANCEL,
   "menu_swap_ok_cancel"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_INPUT_SWAP_SCROLL,
   "menu_swap_scroll"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_AUTODETECT_ENABLE,
   "input_autodetect_enable"
   )
#if defined(HAVE_DINPUT) || defined(HAVE_WINRAWINPUT)
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_NOWINKEY_ENABLE,
   "input_nowinkey_enable"
   )
#endif
#ifdef ANDROID
MSG_HASH(
        MENU_ENUM_LABEL_INPUT_SELECT_PHYSICAL_KEYBOARD,
        "input_android_physical_keyboard"
)
#endif
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_SENSORS_ENABLE,
   "input_sensors_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_AUTO_MOUSE_GRAB,
   "input_auto_mouse_grab"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_AUTO_GAME_FOCUS,
   "input_auto_game_focus"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_BUTTON_AXIS_THRESHOLD,
   "input_axis_threshold"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_ANALOG_DEADZONE,
   "input_analog_deadzone"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_ANALOG_SENSITIVITY,
   "input_analog_sensitivity"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_SENSOR_ACCELEROMETER_SENSITIVITY,
   "input_sensor_accelerometer_sensitivity"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_SENSOR_GYROSCOPE_SENSITIVITY,
   "input_sensor_gyroscope_sensitivity"
   )
#ifdef GEKKO
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_MOUSE_SCALE,
   "input_mouse_scale"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_TOUCH_SCALE,
   "input_touch_scale"
   )
#ifdef UDEV_TOUCH_SUPPORT
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_TOUCH_VMOUSE_POINTER,
   "input_touch_vmouse_pointer"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_TOUCH_VMOUSE_MOUSE,
   "input_touch_vmouse_mouse"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_TOUCH_VMOUSE_TOUCHPAD,
   "input_touch_vmouse_touchpad"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_TOUCH_VMOUSE_TRACKBALL,
   "input_touch_vmouse_trackball"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_TOUCH_VMOUSE_GESTURE,
   "input_touch_vmouse_gesture"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_BIND_TIMEOUT,
   "input_bind_timeout"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_BIND_HOLD,
   "input_bind_hold"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_BLOCK_TIMEOUT,
   "input_block_timeout"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DESCRIPTOR_HIDE_UNBOUND,
   "input_descriptor_hide_unbound"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DESCRIPTOR_LABEL_SHOW,
   "input_descriptor_label_show"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER,
   "input_driver"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_RETROPAD_BINDS,
   "input_retropad_binds"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_HOTKEY_BINDS,
   "input_hotkey_binds"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_HOTKEY_BINDS_BEGIN,
   "input_hotkey_binds_begin"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_HOTKEY_BLOCK_DELAY,
   "input_hotkey_block_delay"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_HOTKEY_DEVICE_MERGE,
   "input_hotkey_device_merge"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_ICADE_ENABLE,
   "input_icade_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_KEYBOARD_GAMEPAD_MAPPING_TYPE,
   "keyboard_gamepad_mapping_type"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_LIBRETRO_DEVICE,
   "input_libretro_device_p%u"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_PLAYER_ANALOG_DPAD_MODE,
   "input_player%u_analog_dpad_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DEVICE_INDEX,
   "input_device_p%u"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DEVICE_RESERVED_DEVICE_NAME,
   "input_device_reserved_device_p%u"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DEVICE_RESERVATION_TYPE,
   "input_device_reservation_type_p%u"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_MOUSE_INDEX,
   "input_player%u_mouse_index"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_JOYPAD_INDEX,
   "input_player%u_joypad_index"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_BIND_ALL_INDEX,
   "input_player%u_bind_all"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_SAVE_AUTOCONFIG_INDEX,
   "input_player%u_bind_all_save_autoconfig"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_BIND_DEFAULTS_INDEX,
   "input_player%u_bind_all_bind_defaults"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_REMAP_PORT,
   "input_remap_port_p%u"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_MAX_USERS,
   "input_max_users"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_MENU_ENUM_TOGGLE_GAMEPAD_COMBO,
   "input_menu_toggle_gamepad_combo"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_QUIT_GAMEPAD_COMBO,
   "input_quit_gamepad_combo"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY,
   "input_overlay"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OSK_OVERLAY,
   "input_osk_overlay"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_ENABLE,
   "input_overlay_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_BEHIND_MENU,
   "overlay_behind_menu"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_HIDE_IN_MENU,
   "overlay_hide_in_menu"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_HIDE_WHEN_GAMEPAD_CONNECTED,
   "overlay_hide_when_gamepad_connected"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_SHOW_INPUTS,
   "input_overlay_show_inputs"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_SHOW_INPUTS_PORT,
   "input_overlay_show_inputs_port"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_SHOW_MOUSE_CURSOR,
   "overlay_show_mouse_cursor"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_AUTO_ROTATE,
   "input_overlay_auto_rotate"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_AUTO_SCALE,
   "input_overlay_auto_scale"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OSK_OVERLAY_AUTO_SCALE,
   "input_osk_overlay_auto_scale"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_POINTER_ENABLE,
   "input_overlay_pointer_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_LIGHTGUN_PORT,
   "input_overlay_lightgun_port"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_LIGHTGUN_TRIGGER_ON_TOUCH,
   "input_overlay_lightgun_trigger_on_touch"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_LIGHTGUN_TRIGGER_DELAY,
   "input_overlay_lightgun_trigger_delay"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_LIGHTGUN_ALLOW_OFFSCREEN,
   "input_overlay_lightgun_allow_offscreen"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_LIGHTGUN_TWO_TOUCH_INPUT,
   "input_overlay_lightgun_two_touch_input"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_LIGHTGUN_THREE_TOUCH_INPUT,
   "input_overlay_lightgun_three_touch_input"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_LIGHTGUN_FOUR_TOUCH_INPUT,
   "input_overlay_lightgun_four_touch_input"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_MOUSE_SPEED,
   "input_overlay_mouse_speed"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_MOUSE_HOLD_TO_DRAG,
   "input_overlay_mouse_hold_to_drag"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_MOUSE_HOLD_MSEC,
   "input_overlay_mouse_hold_msec"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_MOUSE_DTAP_TO_DRAG,
   "input_overlay_mouse_dtap_to_drag"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_MOUSE_DTAP_MSEC,
   "input_overlay_mouse_dtap_msec"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_MOUSE_SWIPE_THRESHOLD,
   "input_overlay_mouse_swipe_threshold"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_DPAD_DIAGONAL_SENSITIVITY,
   "input_overlay_dpad_diagonal_sensitivity"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_ABXY_DIAGONAL_SENSITIVITY,
   "input_overlay_abxy_diagonal_sensitivity"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_OVERLAY_ANALOG_RECENTER_ZONE,
   "input_overlay_analog_recenter_zone"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_POLL_TYPE_BEHAVIOR,
   "input_poll_type_behavior"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_PREFER_FRONT_TOUCH,
   "input_prefer_front_touch"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_REMAPPING_DIRECTORY,
   "input_remapping_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_REMAP_BINDS_ENABLE,
   "input_remap_binds_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_REMAP_SORT_BY_CONTROLLER_ENABLE,
   "input_remap_sort_by_controller_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_SETTINGS,
   "input_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_SETTINGS_BEGIN,
   "input_settings_begin"
   )
MSG_HASH(
   MENU_ENUM_LABEL_LATENCY_SETTINGS,
   "latency_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_SMALL_KEYBOARD_ENABLE,
   "input_small_keyboard_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_TOUCH_ENABLE,
   "input_touch_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_USER_10_BINDS,
   "10_input_binds_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_USER_11_BINDS,
   "11_input_binds_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_USER_12_BINDS,
   "12_input_binds_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_USER_13_BINDS,
   "13_input_binds_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_USER_14_BINDS,
   "14_input_binds_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_USER_15_BINDS,
   "15_input_binds_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_USER_16_BINDS,
   "16_input_binds_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_USER_1_BINDS,
   "1_input_binds_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_USER_2_BINDS,
   "2_input_binds_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_USER_3_BINDS,
   "3_input_binds_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_USER_4_BINDS,
   "4_input_binds_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_USER_5_BINDS,
   "5_input_binds_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_USER_6_BINDS,
   "6_input_binds_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_USER_7_BINDS,
   "7_input_binds_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_USER_8_BINDS,
   "8_input_binds_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_USER_9_BINDS,
   "9_input_binds_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_AUTOCONFIG_DIR,
   "joypad_autoconfig_dir"
   )
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER,
   "input_joypad_driver"
   )
MSG_HASH(
   MENU_ENUM_LABEL_LAKKA_SERVICES,
   "lakka_services"
   )
MSG_HASH(
   MENU_ENUM_LABEL_LIBRETRO_DIR_PATH,
   "libretro_dir_path"
   )
MSG_HASH(
   MENU_ENUM_LABEL_LIBRETRO_INFO_PATH,
   "libretro_info_path"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FRONTEND_LOG_LEVEL,
   "frontend_log_level"
   )
MSG_HASH(
   MENU_ENUM_LABEL_LIBRETRO_LOG_LEVEL,
   "libretro_log_level"
   )
MSG_HASH(
   MENU_ENUM_LABEL_LOAD_ARCHIVE,
   "load_archive"
   )
MSG_HASH(
   MENU_ENUM_LABEL_LOAD_ARCHIVE_DETECT_CORE,
   "load_archive_detect_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_LOAD_CONTENT_HISTORY,
   "load_recent"
   )
MSG_HASH(
   MENU_ENUM_LABEL_LOAD_DISC,
   "load_disc"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DUMP_DISC,
   "dump_disc"
   )
#ifdef HAVE_LAKKA
MSG_HASH(
   MENU_ENUM_LABEL_EJECT_DISC,
   "eject_disc"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_LOAD_CONTENT_SPECIAL,
   "load_special"
   )
MSG_HASH(
   MENU_ENUM_LABEL_LOAD_CONTENT_LIST,
   "load_content"
   )
MSG_HASH(
   MENU_ENUM_LABEL_LOAD_STATE,
   "load_state"
   )
MSG_HASH(
   MENU_ENUM_LABEL_LOCATION_ALLOW,
   "location_allow"
   )
MSG_HASH(
   MENU_ENUM_LABEL_LOCATION_DRIVER,
   "location_driver"
   )
MSG_HASH(
   MENU_ENUM_LABEL_LOGGING_SETTINGS,
   "logging_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_LOG_VERBOSITY,
   "log_verbosity"
   )
MSG_HASH(
   MENU_ENUM_LABEL_LOG_TO_FILE,
   "log_to_file"
   )
MSG_HASH(
   MENU_ENUM_LABEL_LOG_TO_FILE_TIMESTAMP,
   "log_to_file_timestamp"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MAIN_MENU,
   "main_menu"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MANAGEMENT,
   "database_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RGUI_MENU_COLOR_THEME,
   "rgui_menu_color_theme"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RGUI_MENU_THEME_PRESET,
   "rgui_menu_theme_preset"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OZONE_FONT,
   "ozone_font"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OZONE_MENU_COLOR_THEME,
   "ozone_menu_color_theme"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OZONE_COLLAPSE_SIDEBAR,
   "ozone_collapse_sidebar"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OZONE_TRUNCATE_PLAYLIST_NAME,
   "ozone_truncate_playlist_name"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OZONE_SORT_AFTER_TRUNCATE_PLAYLIST_NAME,
   "ozone_sort_after_truncate_playlist_name"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OZONE_SCROLL_CONTENT_METADATA,
   "ozone_scroll_content_metadata"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OZONE_THUMBNAIL_SCALE_FACTOR,
   "ozone_menu_thumbnail_scale_factor"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MATERIALUI_MENU_COLOR_THEME,
   "materialui_menu_color_theme"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MATERIALUI_MENU_TRANSITION_ANIMATION,
   "materialui_menu_transition_animation"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MATERIALUI_MENU_THUMBNAIL_VIEW_PORTRAIT,
   "materialui_thumbnail_view_portrait"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MATERIALUI_MENU_THUMBNAIL_VIEW_LANDSCAPE,
   "materialui_thumbnail_view_landscape"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MATERIALUI_MENU_FOOTER_OPACITY,
   "materialui_menu_footer_opacity"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MATERIALUI_MENU_HEADER_OPACITY,
   "materialui_menu_header_opacity"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_DRIVER,
   "menu_driver"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_DRIVER_RGUI,
   "rgui"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_DRIVER_OZONE,
   "ozone"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_DRIVER_MATERIALUI,
   "glui"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_DRIVER_XMB,
   "xmb"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_FILE_BROWSER_SETTINGS,
   "menu_file_browser_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_LINEAR_FILTER,
   "menu_linear_filter"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_HORIZONTAL_ANIMATION,
   "menu_horizontal_animation"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SETTINGS,
   "menu_settings"
   )
#ifdef _3DS
MSG_HASH(
   MENU_ENUM_LABEL_MENU_BOTTOM_SETTINGS,
   "menu_bottom_settings"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_MENU_WALLPAPER,
   "menu_wallpaper"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_WALLPAPER_OPACITY,
   "menu_wallpaper_opacity"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MOUSE_ENABLE,
   "menu_mouse_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MUSIC_TAB,
   "music_tab"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NAVIGATION_BROWSER_FILTER_SUPPORTED_EXTENSIONS_ENABLE,
   "menu_navigation_browser_filter_supported_extensions_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NAVIGATION_WRAPAROUND,
   "menu_navigation_wraparound_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY,
   "netplay"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_CHECK_FRAMES,
   "netplay_check_frames"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_REQUEST_DEVICE_I,
   "netplay_request_device_%u"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_SHARE_ANALOG,
   "netplay_share_analog"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_SHARE_DIGITAL,
   "netplay_share_digital"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_INPUT_LATENCY_FRAMES_MIN,
   "netplay_input_latency_frames_min"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_INPUT_LATENCY_FRAMES_RANGE,
   "netplay_input_latency_frames_range"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_DISCONNECT,
   "menu_netplay_disconnect"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_ENABLE,
   "netplay_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_ENABLE_CLIENT,
   "menu_netplay_enable_client"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_ENABLE_HOST,
   "menu_netplay_enable_host"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_KICK,
   "menu_netplay_kick"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_BAN,
   "menu_netplay_ban"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_ALLOW_SLAVES,
   "netplay_allow_slaves"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_IP_ADDRESS,
   "netplay_ip_address"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_MODE,
   "netplay_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_NAT_TRAVERSAL,
   "netplay_nat_traversal"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_NICKNAME,
   "netplay_nickname"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_PASSWORD,
   "netplay_password"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_SETTINGS,
   "menu_netplay_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_PUBLIC_ANNOUNCE,
   "netplay_public_announce"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_REQUIRE_SLAVES,
   "netplay_require_slaves"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_SPECTATE_PASSWORD,
   "netplay_spectate_password"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_SPECTATOR_MODE_ENABLE,
   "netplay_spectator_mode_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_START_AS_SPECTATOR,
   "netplay_start_as_spectator"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_FADE_CHAT,
   "netplay_fade_chat"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_CHAT_COLOR_NAME,
   "netplay_chat_color_name"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_CHAT_COLOR_MSG,
   "netplay_chat_color_msg"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_ALLOW_PAUSING,
   "netplay_allow_pausing"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_TCP_UDP_PORT,
   "netplay_tcp_udp_port"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_MAX_CONNECTIONS,
   "netplay_max_connections"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_MAX_PING,
   "netplay_max_ping"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_LAN_SCAN_SETTINGS,
   "Search for and connect to netplay hosts on the local network."
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETWORK_CMD_ENABLE,
   "network_cmd_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETWORK_CMD_PORT,
   "network_cmd_port"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETWORK_INFORMATION,
   "network_information"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETWORK_INFO_ENTRY,
   "network_info_entry"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETWORK_REMOTE_ENABLE,
   "network_remote_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETWORK_REMOTE_PORT,
   "network_remote_base_port"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETWORK_REMOTE_USER_1_ENABLE,
   "network_remote_user_1_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETWORK_REMOTE_USER_LAST_ENABLE,
   "network_remote_user_last_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETWORK_ON_DEMAND_THUMBNAILS,
   "network_on_demand_thumbnails"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SUBSYSTEM_SETTINGS,
   "subsystem_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETWORK_HOSTING_SETTINGS,
   "network_hosting_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETWORK_SETTINGS,
   "network_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_LOBBY_FILTERS,
   "netplay_lobby_filters"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_ACHIEVEMENTS_TO_DISPLAY,
   "no_achievements_to_display"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_CORES_AVAILABLE,
   "no_cores_available"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_CORE_INFORMATION_AVAILABLE,
   "no_core_information_available"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_CORE_BACKUPS_AVAILABLE,
   "no_core_backups_available"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_CORE_OPTIONS_AVAILABLE,
   "no_core_options_available"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_ENTRIES_TO_DISPLAY,
   "no_entries_to_display"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_HISTORY_AVAILABLE,
   "no_history"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_ITEMS,
   "no_items"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_NETPLAY_HOSTS_FOUND,
   "no_netplay_hosts_found"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_NETPLAY_CLIENTS_FOUND,
   "no_netplay_clients_found"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_BT_DEVICES_FOUND,
   "no_bt_devices_found"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_NETWORKS_FOUND,
   "no_networks_found"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_PERFORMANCE_COUNTERS,
   "no_performance_counters"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_PLAYLISTS,
   "no_playlists"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_PLAYLIST_ENTRIES_AVAILABLE,
   "no_playlist_entries_available"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_SETTINGS_FOUND,
   "menu_label_no_settings_found"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_PRESETS_FOUND,
   "menu_label_no_presets_found"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_SHADER_PARAMETERS,
   "no_shader_parameters."
   )
MSG_HASH(
   MENU_ENUM_LABEL_ONLINE,
   "online"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ONLINE_UPDATER,
   "online_updater"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ONSCREEN_DISPLAY_SETTINGS,
   "onscreen_display_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ONSCREEN_OVERLAY_SETTINGS,
   "onscreen_overlay_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERLAY_LIGHTGUN_SETTINGS,
   "overlay_lightgun_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERLAY_MOUSE_SETTINGS,
   "overlay_mouse_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OSK_OVERLAY_SETTINGS,
   "osk_overlay_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ONSCREEN_VIDEO_LAYOUT_SETTINGS,
   "onscreen_video_layout_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ONSCREEN_NOTIFICATIONS_SETTINGS,
   "onscreen_notifications_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ONSCREEN_NOTIFICATIONS_VIEWS_SETTINGS,
   "onscreen_notifications_views_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OPEN_ARCHIVE,
   "open_archive"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OPEN_ARCHIVE_DETECT_CORE,
   "open_archive_detect_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERLAY_AUTOLOAD_PREFERRED,
   "overlay_autoload_preferred"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERLAY_DIRECTORY,
   "overlay_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OSK_OVERLAY_DIRECTORY,
   "osk_overlay_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_LAYOUT_DIRECTORY,
   "video_layout_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERLAY_OPACITY,
   "input_overlay_opacity"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OSK_OVERLAY_OPACITY,
   "input_osk_overlay_opacity"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERLAY_PRESET,
   "input_overlay"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OSK_OVERLAY_PRESET,
   "input_osk_overlay"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERLAY_SCALE_LANDSCAPE,
   "input_overlay_scale_landscape"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERLAY_ASPECT_ADJUST_LANDSCAPE,
   "input_overlay_aspect_adjust_landscape"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERLAY_X_SEPARATION_LANDSCAPE,
   "input_overlay_x_separation_landscape"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERLAY_Y_SEPARATION_LANDSCAPE,
   "input_overlay_y_separation_landscape"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERLAY_X_OFFSET_LANDSCAPE,
   "input_overlay_x_offset_landscape"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERLAY_Y_OFFSET_LANDSCAPE,
   "input_overlay_y_offset_landscape"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERLAY_SCALE_PORTRAIT,
   "input_overlay_scale_portrait"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERLAY_ASPECT_ADJUST_PORTRAIT,
   "input_overlay_aspect_adjust_portrait"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERLAY_X_SEPARATION_PORTRAIT,
   "input_overlay_x_separation_portrait"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERLAY_Y_SEPARATION_PORTRAIT,
   "input_overlay_y_separation_portrait"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERLAY_X_OFFSET_PORTRAIT,
   "input_overlay_x_offset_portrait"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERLAY_Y_OFFSET_PORTRAIT,
   "input_overlay_y_offset_portrait"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PAL60_ENABLE,
   "pal60_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PARENT_DIRECTORY,
   "parent_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PAUSE_LIBRETRO,
   "menu_pause_libretro"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SAVESTATE_RESUME,
   "menu_savestate_resume"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_INSERT_DISK_RESUME,
   "menu_insert_disk_resume"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUIT_ON_CLOSE_CONTENT,
   "quit_on_close_content"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PAUSE_NONACTIVE,
   "pause_nonactive"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PAUSE_ON_DISCONNECT,
   "pause_on_disconnect"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SCREENSAVER_TIMEOUT,
   "menu_screensaver_timeout"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SCREENSAVER_ANIMATION,
   "menu_screensaver_animation"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SCREENSAVER_ANIMATION_SPEED,
   "menu_screensaver_animation_speed"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PERFCNT_ENABLE,
   "perfcnt_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLISTS_TAB,
   "playlists_tab"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_COLLECTION_ENTRY,
   "playlist_collection_entry"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_DIRECTORY,
   "playlist_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_FAVORITES_DIRECTORY,
   "content_favorites_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_HISTORY_DIRECTORY,
   "content_history_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_IMAGE_HISTORY_DIRECTORY,
   "content_image_history_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_MUSIC_HISTORY_DIRECTORY,
   "content_music_history_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_VIDEO_HISTORY_DIRECTORY,
   "content_video_history_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RUNTIME_LOG_DIRECTORY,
   "runtime_log_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_ENTRY,
   "playlist_entry"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_SETTINGS,
   "playlist_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_MANAGER_LIST,
   "playlist_manager_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_MANAGER_SETTINGS,
   "playlist_manager_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_MANAGER_DEFAULT_CORE,
   "playlist_manager_default_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_MANAGER_RESET_CORES,
   "playlist_manager_reset_cores"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_MANAGER_LABEL_DISPLAY_MODE,
   "playlist_manager_label_display_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_MANAGER_RIGHT_THUMBNAIL_MODE,
   "playlist_manager_right_thumbnail_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_MANAGER_LEFT_THUMBNAIL_MODE,
   "playlist_manager_left_thumbnail_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_MANAGER_SORT_MODE,
   "playlist_manager_sort_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_MANAGER_CLEAN_PLAYLIST,
   "playlist_manager_clean_playlist"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_MANAGER_REFRESH_PLAYLIST,
   "playlist_manager_refresh_playlist"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_SETTINGS_BEGIN,
   "playlist_settings_begin"
   )
MSG_HASH(
   MENU_ENUM_LABEL_POINTER_ENABLE,
   "menu_pointer_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PRIVACY_SETTINGS,
   "privacy_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MIDI_SETTINGS,
   "midi_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUIT_RETROARCH,
   "quit_retroarch"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CLOUD_SYNC_SYNC_NOW,
   "cloud_sync_sync_now"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY,
   "rdb_entry"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_DETAIL,
   "rdb_entry_detail"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_ANALOG,
   "rdb_entry_analog"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_BBFC_RATING,
   "rdb_entry_bbfc_rating"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_CERO_RATING,
   "rdb_entry_cero_rating"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_CRC32,
   "rdb_entry_crc32"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_DESCRIPTION,
   "rdb_entry_description"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DUMP_DISC_LIST,
   "deferred_dump_disc_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_LOAD_DISC_LIST,
   "deferred_load_disc_list"
   )
#ifdef HAVE_LAKKA
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_EJECT_DISC,
   "deferred_eject_disc"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CURSOR_MANAGER_LIST_RDB_ENTRY_DEVELOPER,
   "deferred_cursor_manager_list_rdb_entry_developer"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CURSOR_MANAGER_LIST_RDB_ENTRY_PUBLISHER,
   "deferred_cursor_manager_list_rdb_entry_publisher"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CURSOR_MANAGER_LIST_RDB_ENTRY_ORIGIN,
   "deferred_cursor_manager_list_rdb_entry_origin"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CURSOR_MANAGER_LIST_RDB_ENTRY_FRANCHISE,
   "deferred_cursor_manager_list_rdb_entry_franchise"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CURSOR_MANAGER_LIST_RDB_ENTRY_EDGE_MAGAZINE_RATING,
   "deferred_cursor_manager_list_rdb_entry_edge_magazine_rating"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CURSOR_MANAGER_LIST_RDB_ENTRY_EDGE_MAGAZINE_ISSUE,
   "deferred_cursor_manager_list_rdb_entry_edge_magazine_issue"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CURSOR_MANAGER_LIST_RDB_ENTRY_FAMITSU_MAGAZINE_RATING,
   "deferred_cursor_manager_list_rdb_entry_famitsu_magazine_rating"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CURSOR_MANAGER_LIST_RDB_ENTRY_ENHANCEMENT_HW,
   "deferred_cursor_manager_list_rdb_entry_enhancement_hw"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CURSOR_MANAGER_LIST_RDB_ENTRY_RELEASEMONTH,
   "deferred_cursor_manager_list_rdb_entry_releasemonth"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CURSOR_MANAGER_LIST_RDB_ENTRY_RELEASEYEAR,
   "deferred_cursor_manager_list_rdb_entry_releaseyear"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CURSOR_MANAGER_LIST_RDB_ENTRY_ESRB_RATING,
   "deferred_cursor_manager_list_rdb_entry_esrb_rating"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CURSOR_MANAGER_LIST_RDB_ENTRY_ELSPA_RATING,
   "deferred_cursor_manager_list_rdb_entry_elspa_rating"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CURSOR_MANAGER_LIST_RDB_ENTRY_PEGI_RATING,
   "deferred_cursor_manager_list_rdb_entry_pegi_rating"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CURSOR_MANAGER_LIST_RDB_ENTRY_CERO_RATING,
   "deferred_cursor_manager_list_rdb_entry_cero_rating"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CURSOR_MANAGER_LIST_RDB_ENTRY_BBFC_RATING,
   "deferred_cursor_manager_list_rdb_entry_bbfc_rating"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CURSOR_MANAGER_LIST_RDB_ENTRY_MAX_USERS,
   "deferred_cursor_manager_list_rdb_entry_max_users"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CURSOR_MANAGER_LIST_RDB_ENTRY_GENRE,
   "deferred_cursor_manager_list_rdb_entry_genre"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_CURSOR_MANAGER_LIST_RDB_ENTRY_REGION,
   "deferred_cursor_manager_list_rdb_entry_region"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_DEVELOPER,
   "rdb_entry_developer"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_EDGE_MAGAZINE_ISSUE,
   "rdb_entry_edge_magazine_issue"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_EDGE_MAGAZINE_RATING,
   "rdb_entry_edge_magazine_rating"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_EDGE_MAGAZINE_REVIEW,
   "rdb_entry_edge_magazine_review"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_ELSPA_RATING,
   "rdb_entry_elspa_rating"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_ENHANCEMENT_HW,
   "rdb_entry_enhancement_hw"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_ESRB_RATING,
   "rdb_entry_esrb_rating"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_FAMITSU_MAGAZINE_RATING,
   "rdb_entry_famitsu_magazine_rating"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_FRANCHISE,
   "rdb_entry_franchise"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_GENRE,
   "rdb_entry_genre"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_ACHIEVEMENTS,
   "rdb_entry_achievements"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_CATEGORY,
   "rdb_entry_category"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_LANGUAGE,
   "rdb_entry_language"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_REGION,
   "rdb_entry_region"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_CONSOLE_EXCLUSIVE,
   "rdb_entry_console_exclusive"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_PLATFORM_EXCLUSIVE,
   "rdb_entry_platform_exclusive"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_RUMBLE,
   "rdb_entry_rumble"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_SCORE,
   "rdb_entry_score"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_MEDIA,
   "rdb_entry_media"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_CONTROLS,
   "rdb_entry_controls"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_ARTSTYLE,
   "rdb_entry_artstyle"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_GAMEPLAY,
   "rdb_entry_gameplay"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_NARRATIVE,
   "rdb_entry_narrative"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_PACING,
   "rdb_entry_pacing"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_PERSPECTIVE,
   "rdb_entry_perspective"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_SETTING,
   "rdb_entry_setting"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_VISUAL,
   "rdb_entry_visual"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_VEHICULAR,
   "rdb_entry_vehicular"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_MAX_USERS,
   "rdb_entry_max_users"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_MD5,
   "rdb_entry_md5"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_NAME,
   "rdb_entry_name"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_ORIGIN,
   "rdb_entry_origin"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_PEGI_RATING,
   "rdb_entry_pegi_rating"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_PUBLISHER,
   "rdb_entry_publisher"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_RELEASE_MONTH,
   "rdb_entry_releasemonth"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_RELEASE_YEAR,
   "rdb_entry_releaseyear"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_SERIAL,
   "rdb_entry_serial"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_SHA1,
   "rdb_entry_sha1"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_START_CONTENT,
   "rdb_entry_start_content"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RDB_ENTRY_TGDB_RATING,
   "rdb_entry_tgdb_rating"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_INFO_LABEL,
   "content_info_label"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_INFO_PATH,
   "content_info_path"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_INFO_CORE_NAME,
   "content_info_core_name"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_INFO_DATABASE,
   "content_info_database"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_INFO_RUNTIME,
   "content_info_runtime"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_INFO_LAST_PLAYED,
   "content_info_last_played"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REBOOT,
   "reboot"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RECORDING_CONFIG_DIRECTORY,
   "recording_config_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RECORDING_OUTPUT_DIRECTORY,
   "recording_output_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RECORDING_SETTINGS,
   "recording_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RECORD_CONFIG,
   "record_config"
   )
MSG_HASH(
   MENU_ENUM_LABEL_STREAM_CONFIG,
   "stream_config"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RECORD_DRIVER,
   "record_driver"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MIDI_DRIVER,
   "midi_driver"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RECORD_ENABLE,
   "record_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RECORD_PATH,
   "record_path"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RECORD_USE_OUTPUT_DIRECTORY,
   "record_use_output_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_REMAP_FILE_MANAGER_LIST,
   "deferred_remap_file_manager_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REMAP_FILE_MANAGER_LIST,
   "remap_file_manager_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REMAP_FILE_INFO,
   "remap_file_info"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REMAP_FILE_LOAD,
   "remap_file_load"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REMAP_FILE_SAVE_AS,
   "remap_file_save_as"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REMAP_FILE_SAVE_CORE,
   "remap_file_save_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REMAP_FILE_SAVE_CONTENT_DIR,
   "remap_file_save_content_dir"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REMAP_FILE_SAVE_GAME,
   "remap_file_save_game"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REMAP_FILE_REMOVE_CONTENT_DIR,
   "remap_file_remove_content_dir"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REMAP_FILE_REMOVE_CORE,
   "remap_file_remove_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REMAP_FILE_REMOVE_GAME,
   "remap_file_remove_game"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REMAP_FILE_RESET,
   "remap_file_reset"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REMAP_FILE_FLUSH,
   "remap_file_flush"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RESTART_CONTENT,
   "restart_content"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RESTART_RETROARCH,
   "restart_retroarch"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RESUME_CONTENT,
   "resume_content"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RETRO_ACHIEVEMENTS_SETTINGS,
   "retro_achievements_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_META_REWIND,
   "input_meta_rewind"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REWIND_ENABLE,
   "rewind_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_APPLY_AFTER_TOGGLE,
   "cheat_apply_after_toggle"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_APPLY_AFTER_LOAD,
   "cheat_apply_after_load"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REWIND_GRANULARITY,
   "rewind_granularity"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REWIND_BUFFER_SIZE,
   "rewind_buffer_size"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REWIND_BUFFER_SIZE_STEP,
   "rewind_buffer_size_step"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REWIND_SETTINGS,
   "rewind_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FRAME_TIME_COUNTER_SETTINGS,
   "frame_time_counter_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VRR_RUNLOOP_ENABLE,
   "vrr_runloop_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_THROTTLE_FRAMERATE,
   "menu_throttle_framerate"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_ENUM_THROTTLE_FRAMERATE,
   "menu_throttle_framerate"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_SETTINGS,
   "cheat_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RGUI_BROWSER_DIRECTORY,
   "rgui_browser_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RGUI_CONFIG_DIRECTORY,
   "rgui_config_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RGUI_SHOW_START_SCREEN,
   "rgui_show_start_screen"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ADD_TO_FAVORITES,
   "favorites_add"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ADD_TO_FAVORITES_PLAYLIST,
   "favorites_add_playlist"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ADD_TO_PLAYLIST,
   "playlist_add"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_ADD_TO_PLAYLIST_LIST,
   "deferred_add_to_playlist_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ADD_ENTRY_TO_PLAYLIST,
   "add_entry_to_playlist"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CREATE_NEW_PLAYLIST,
   "playlist_create"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ADD_TO_PLAYLIST_QUICKMENU,
   "playlist_add_quickmenu"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_ADD_TO_PLAYLIST_QUICKMENU,
   "deferred_add_to_playlist_quickmenu"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ADD_ENTRY_TO_PLAYLIST_QUICKMENU,
   "add_entry_to_playlist_quickmenu"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CREATE_NEW_PLAYLIST_QUICKMENU,
   "playlist_create_quickmenu"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SET_CORE_ASSOCIATION,
   "set_core_association"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RESET_CORE_ASSOCIATION,
   "reset_core_association"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DOWNLOAD_PL_ENTRY_THUMBNAILS,
   "download_pl_entry_thumbnails"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RUN,
   "collection"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RUN_MUSIC,
   "collection_music"
   )
#ifdef HAVE_LAKKA
MSG_HASH(
   MENU_ENUM_LABEL_SAMBA_ENABLE,
   "samba_enable"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_SAVEFILE_DIRECTORY,
   "savefile_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SAVESTATE_AUTO_INDEX,
   "savestate_auto_index"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SAVESTATE_AUTO_LOAD,
   "savestate_auto_load"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SAVESTATE_THUMBNAIL_ENABLE,
   "savestate_thumbnails"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SAVE_FILE_COMPRESSION,
   "save_file_compression"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SAVESTATE_FILE_COMPRESSION,
   "savestate_file_compression"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SAVESTATE_AUTO_SAVE,
   "savestate_auto_save"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SAVESTATE_MAX_KEEP,
   "savestate_max_keep"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REPLAY_AUTO_INDEX,
   "replay_auto_index"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REPLAY_MAX_KEEP,
   "replay_max_keep"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SAVESTATE_DIRECTORY,
   "savestate_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SAVE_CURRENT_CONFIG,
   "save_current_config"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERRIDE_FILE_LOAD,
   "override_file_load"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERRIDE_FILE_SAVE_AS,
   "override_file_save_as"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERRIDE_UNLOAD,
   "override_unload"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SAVE_CURRENT_CONFIG_OVERRIDE_CORE,
   "save_current_config_override_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SAVE_CURRENT_CONFIG_OVERRIDE_CONTENT_DIR,
   "save_current_config_override_content_dir"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SAVE_CURRENT_CONFIG_OVERRIDE_GAME,
   "save_current_config_override_game"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REMOVE_CURRENT_CONFIG_OVERRIDE_CORE,
   "remove_current_config_override_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REMOVE_CURRENT_CONFIG_OVERRIDE_CONTENT_DIR,
   "remove_current_config_override_content_dir"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REMOVE_CURRENT_CONFIG_OVERRIDE_GAME,
   "remove_current_config_override_game"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SAVE_NEW_CONFIG,
   "save_new_config"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SAVE_AS_CONFIG,
   "save_as_config"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SAVE_MAIN_CONFIG,
   "save_main_config"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SAVE_STATE,
   "save_state"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RECORD_REPLAY,
   "record_replay"
   )
MSG_HASH(
   MENU_ENUM_LABEL_REPLAY_SLOT,
   "replay_slot"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAY_REPLAY,
   "play_replay"
   )
MSG_HASH(
   MENU_ENUM_LABEL_HALT_REPLAY,
   "halt_replay"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SAVING_SETTINGS,
   "saving_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CLOUD_SYNC_SETTINGS,
   "cloud_sync_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CLOUD_SYNC_ENABLE,
   "cloud_sync_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CLOUD_SYNC_SYNC_MODE,
   "cloud_sync_sync_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CLOUD_SYNC_SYNC_MODE_AUTOMATIC,
   "cloud_sync_sync_mode_automatic"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CLOUD_SYNC_SYNC_MODE_MANUAL,
   "cloud_sync_sync_mode_manual"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CLOUD_SYNC_DESTRUCTIVE,
   "cloud_sync_destructive"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CLOUD_SYNC_SYNC_SAVES,
   "cloud_sync_sync_saves"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CLOUD_SYNC_SYNC_CONFIGS,
   "cloud_sync_sync_configs"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CLOUD_SYNC_SYNC_THUMBS,
   "cloud_sync_sync_thumbs"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CLOUD_SYNC_SYNC_SYSTEM,
   "cloud_sync_sync_system"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CLOUD_SYNC_DRIVER,
   "cloud_sync_driver"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CLOUD_SYNC_URL,
   "cloud_sync_url"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CLOUD_SYNC_USERNAME,
   "cloud_sync_username"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CLOUD_SYNC_PASSWORD,
   "cloud_sync_password"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SCAN_DIRECTORY,
   "scan_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SCAN_FILE,
   "scan_file"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_SHOW_ONLY_CONNECTABLE,
   "netplay_show_only_connectable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_SHOW_ONLY_INSTALLED_CORES,
   "netplay_show_only_installed_cores"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_SHOW_PASSWORDED,
   "netplay_show_passworded"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_REFRESH_ROOMS,
   "refresh_rooms"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_REFRESH_LAN,
   "refresh_lan"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SCAN_THIS_DIRECTORY,
   "scan_this_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SCREENSHOT_DIRECTORY,
   "screenshot_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SCREEN_RESOLUTION,
   "screen_resolution"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS,
   "settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_TAB,
   "settings_tab"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SHOW_ADVANCED_SETTINGS,
   "menu_show_advanced_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SHOW_HIDDEN_FILES,
   "show_hidden_files"
   )
MSG_HASH(
   MENU_ENUM_LABEL_USE_LAST_START_DIRECTORY,
   "use_last_start_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SHUTDOWN,
   "shutdown"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SLOWMOTION_RATIO,
   "slowmotion_ratio"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RUN_AHEAD_UNSUPPORTED,
   "run_ahead_unsupported"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RUNAHEAD_MODE,
   "run_ahead_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RUN_AHEAD_HIDE_WARNINGS,
   "run_ahead_hide_warnings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RUN_AHEAD_FRAMES,
   "run_ahead_frames"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PREEMPT_FRAMES,
   "preemptive_frames"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SORT_SAVEFILES_ENABLE,
   "sort_savefiles_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SORT_SAVESTATES_ENABLE,
   "sort_savestates_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SORT_SAVEFILES_BY_CONTENT_ENABLE,
   "sort_savefiles_by_content_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SORT_SAVESTATES_BY_CONTENT_ENABLE,
   "sort_savestates_by_content_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SORT_SCREENSHOTS_BY_CONTENT_ENABLE,
   "sort_screenshots_by_content_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SAVEFILES_IN_CONTENT_DIR_ENABLE,
   "savefiles_in_content_dir_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SAVESTATES_IN_CONTENT_DIR_ENABLE,
   "savestates_in_content_dir_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SYSTEMFILES_IN_CONTENT_DIR_ENABLE,
   "systemfiles_in_content_dir_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SCREENSHOTS_IN_CONTENT_DIR_ENABLE,
   "screenshots_in_content_dir_enable"
   )
#ifdef HAVE_LAKKA
MSG_HASH(
   MENU_ENUM_LABEL_SSH_ENABLE,
   "ssh_enable"
   )
#endif

#ifdef HAVE_LAKKA_SWITCH
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_LAKKA_SWITCH_OPTIONS_LIST,
   "deferred_lakka_switch_options_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_LAKKA_SWITCH_OPTIONS,
   "Switch_Options"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SWITCH_OC_ENABLE,
   "Switch_OC_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SWITCH_CEC_ENABLE,
   "Switch_CEC_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_BLUETOOTH_ERTM_DISABLE,
   "Switch_ERTM_Disable"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_START_CORE,
   "start_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_START_NET_RETROPAD,
   "menu_start_net_retropad"
   )
MSG_HASH(
   MENU_ENUM_LABEL_START_GONG,
   "menu_start_gong"
   )
MSG_HASH(
   MENU_ENUM_LABEL_START_VIDEO_PROCESSOR,
   "menu_start_video_processor"
   )
MSG_HASH(
   MENU_ENUM_LABEL_STATE_SLOT,
   "state_slot"
   )
MSG_HASH(
   MENU_ENUM_LABEL_STDIN_CMD_ENABLE,
   "stdin_commands"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SUSPEND_SCREENSAVER_ENABLE,
   "suspend_screensaver_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SYSTEM_BGM_ENABLE,
   "system_bgm_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SYSTEM_DIRECTORY,
   "system_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SYSTEM_INFORMATION,
   "system_information"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SYSTEM_INFO_ENTRY,
   "system_info_entry"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ICON_THUMBNAILS,
   "icon_thumbnails"
   )
MSG_HASH(
   MENU_ENUM_LABEL_TAKE_SCREENSHOT,
   "take_screenshot"
   )
MSG_HASH(
   MENU_ENUM_LABEL_THREADED_DATA_RUNLOOP_ENABLE,
   "threaded_data_runloop_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_THUMBNAILS,
   "thumbnails"
   )
MSG_HASH(
   MENU_ENUM_LABEL_LEFT_THUMBNAILS,
   "left thumbnails"
   )
MSG_HASH(
   MENU_ENUM_LABEL_XMB_VERTICAL_THUMBNAILS,
   "xmb_vertical_thumbnails"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_XMB_THUMBNAIL_SCALE_FACTOR,
   "menu_xmb_thumbnail_scale_factor"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_XMB_VERTICAL_FADE_FACTOR,
   "menu_xmb_vertical_fade_factor"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_XMB_SHOW_TITLE_HEADER,
   "menu_xmb_show_title_header"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_XMB_TITLE_MARGIN,
   "menu_xmb_title_margin"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_XMB_TITLE_MARGIN_HORIZONTAL_OFFSET,
   "menu_xmb_title_margin_horizontal_offset"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_THUMBNAIL_UPSCALE_THRESHOLD,
   "menu_thumbnail_upscale_threshold"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_RGUI_THUMBNAIL_DOWNSCALER,
   "rgui_thumbnail_downscaler"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_RGUI_THUMBNAIL_DELAY,
   "rgui_thumbnail_delay"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_RGUI_INLINE_THUMBNAILS,
   "rgui_inline_thumbnails"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_RGUI_SWAP_THUMBNAILS,
   "rgui_swap_thumbnails"
   )
MSG_HASH(
   MENU_ENUM_LABEL_THUMBNAILS_DIRECTORY,
   "thumbnails_directory"
   )
/* Thumbnailpack removal - next entry is deprecated */
MSG_HASH(
   MENU_ENUM_LABEL_THUMBNAILS_UPDATER_LIST,
   "thumbnails_updater_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PL_THUMBNAILS_UPDATER_LIST,
   "pl_thumbnails_updater_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PL_THUMBNAILS_UPDATER_ENTRY,
   "pl_thumbnails_updater_entry"
   )
MSG_HASH(
   MENU_ENUM_LABEL_TIMEDATE_ENABLE,
   "menu_timedate_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_TIMEDATE_STYLE,
   "menu_timedate_style"
   )
MSG_HASH(
   MENU_ENUM_LABEL_TIMEDATE_DATE_SEPARATOR,
   "menu_timedate_date_separator"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_TICKER_TYPE,
   "menu_ticker_type"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_TICKER_SPEED,
   "menu_ticker_speed"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_TICKER_SMOOTH,
   "menu_ticker_smooth"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_REMEMBER_SELECTION,
   "menu_remember_selection"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_STARTUP_PAGE,
   "menu_startup_page"
   )
MSG_HASH(
   MENU_ENUM_LABEL_UI_COMPANION_ENABLE,
   "ui_companion_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_UI_COMPANION_START_ON_BOOT,
   "ui_companion_start_on_boot"
   )
MSG_HASH(
   MENU_ENUM_LABEL_UI_COMPANION_TOGGLE,
   "ui_companion_toggle"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DESKTOP_MENU_ENABLE,
   "desktop_menu_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_UI_MENUBAR_ENABLE,
   "ui_menubar_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_UNDO_LOAD_STATE,
   "undo_load_state"
   )
MSG_HASH(
   MENU_ENUM_LABEL_UNDO_SAVE_STATE,
   "undo_save_state"
   )
MSG_HASH(
   MENU_ENUM_LABEL_UPDATER_SETTINGS,
   "updater_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_UPDATE_ASSETS,
   "update_assets"
   )
MSG_HASH(
   MENU_ENUM_LABEL_UPDATE_AUTOCONFIG_PROFILES,
   "update_autoconfig_profiles"
   )
MSG_HASH(
   MENU_ENUM_LABEL_UPDATE_CG_SHADERS,
   "update_cg_shaders"
   )
MSG_HASH(
   MENU_ENUM_LABEL_UPDATE_CHEATS,
   "update_cheats"
   )
MSG_HASH(
   MENU_ENUM_LABEL_UPDATE_CORE_INFO_FILES,
   "update_core_info_files"
   )
MSG_HASH(
   MENU_ENUM_LABEL_UPDATE_DATABASES,
   "update_databases"
   )
MSG_HASH(
   MENU_ENUM_LABEL_UPDATE_GLSL_SHADERS,
   "update_glsl_shaders"
   )
MSG_HASH(
   MENU_ENUM_LABEL_UPDATE_LAKKA,
   "update_lakka"
   )
MSG_HASH(
   MENU_ENUM_LABEL_UPDATE_OVERLAYS,
   "update_overlays"
   )
MSG_HASH(
   MENU_ENUM_LABEL_UPDATE_SLANG_SHADERS,
   "update_slang_shaders"
   )
MSG_HASH(
   MENU_ENUM_LABEL_URL_ENTRY,
   "url_entry"
   )
MSG_HASH(
   MENU_ENUM_LABEL_USER_INTERFACE_SETTINGS,
   "user_interface_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_USER_LANGUAGE,
   "user_language"
   )
MSG_HASH(
   MENU_ENUM_LABEL_USER_SETTINGS,
   "user_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_USE_BUILTIN_IMAGE_VIEWER,
   "use_builtin_image_viewer"
   )
MSG_HASH(
   MENU_ENUM_LABEL_USE_BUILTIN_PLAYER,
   "use_builtin_player"
   )
MSG_HASH(
   MENU_ENUM_LABEL_USE_THIS_DIRECTORY,
   "use_this_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_BRIGHTNESS_CONTROL,
   "screen_brightness"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_ALLOW_ROTATE,
   "video_allow_rotate"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CRT_SWITCH_RESOLUTION,
   "crt_switch_resolution"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CRT_SWITCH_RESOLUTION_SUPER,
   "crt_switch_resolution_super"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CRT_SWITCH_X_AXIS_CENTERING,
   "crt_switch_horizontal_shift"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CRT_SWITCH_PORCH_ADJUST,
   "crt_switch_horizontal_size"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CRT_SWITCH_VERTICAL_ADJUST,
   "crt_switch_vertical_size"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_ASPECT_RATIO,
   "video_aspect_ratio"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_ASPECT_RATIO_INDEX,
   "aspect_ratio_index"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_VIEWPORT_BIAS_X,
   "video_viewport_bias_x"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_VIEWPORT_BIAS_Y,
   "video_viewport_bias_y"
   )
#if defined(RARCH_MOBILE)
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_VIEWPORT_BIAS_PORTRAIT_X,
   "video_viewport_bias_portrait_x"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_VIEWPORT_BIAS_PORTRAIT_Y,
   "video_viewport_bias_portrait_y"
   )
#endif
#if defined(DINGUX)
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DINGUX_IPU_KEEP_ASPECT,
   "video_dingux_ipu_keep_aspect"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DINGUX_IPU_FILTER_TYPE,
   "video_dingux_ipu_filter_type"
   )
#if defined(DINGUX_BETA)
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DINGUX_REFRESH_RATE,
   "video_dingux_refresh_rate"
   )
#endif
#if defined(RS90) || defined(MIYOO)
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DINGUX_RS90_SOFTFILTER_TYPE,
   "video_dingux_rs90_softfilter_type"
   )
#endif
#endif
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_BLACK_FRAME_INSERTION,
   "video_black_frame_insertion"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_BFI_DARK_FRAMES,
   "video_bfi_dark_frames"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_SUBFRAMES,
   "video_shader_subframes"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SCAN_SUBFRAMES,
   "video_scan_subframes"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_CROP_OVERSCAN,
   "video_crop_overscan"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DISABLE_COMPOSITION,
   "video_disable_composition"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER,
   "video_driver"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_GL,
   "gl"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_GL1,
   "gl1"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_GL_CORE,
   "glcore"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_VULKAN,
   "vulkan"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_METAL,
   "metal"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_DRM,
   "drm"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_WII,
   "gx"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_WIIU,
   "gx2"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_XENON360,
   "xenon360"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_D3D8,
   "d3d8"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_D3D9_CG,
   "d3d9_cg"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_D3D9_HLSL,
   "d3d9_hlsl"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_D3D10,
   "d3d10"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_D3D11,
   "d3d11"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_D3D12,
   "d3d12"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_PSP1,
   "psp1"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_PS2,
   "ps2"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_VITA2D,
   "vita2d"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_CTR,
   "ctr"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_SWITCH,
   "switch"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_XVIDEO,
   "xvideo"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_SDL_DINGUX,
   "sdl_dingux"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_SDL_RS90,
   "sdl_rs90"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_SDL1,
   "sdl"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_SDL2,
   "sdl2"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_EXT,
   "ext"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_VG,
   "vg"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_OMAP,
   "omap"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_EXYNOS,
   "exynos"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_DISPMANX,
   "dispmanx"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_SUNXI,
   "sunxi"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_CACA,
   "caca"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_GDI,
   "gdi"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_VGA,
   "vga"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_FPGA,
   "fpga"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_RSX,
   "rsx"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_DRIVER_NULL,
   "null"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_FILTER,
   "video_filter"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_FILTER_REMOVE,
   "video_filter_remove"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_FILTER_DIR,
   "video_filter_dir"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_FILTER_FLICKER,
   "video_filter_flicker"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_FONT_ENABLE,
   "video_font_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_FONT_PATH,
   "video_font_path"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_FONT_SIZE,
   "video_font_size"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_FORCE_SRGB_DISABLE,
   "video_force_srgb_disable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_FRAME_DELAY,
   "video_frame_delay"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_FRAME_DELAY_AUTO,
   "video_frame_delay_auto"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_DELAY,
   "video_shader_delay"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_FULLSCREEN,
   "video_fullscreen"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_GAMMA,
   "video_gamma"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_GPU_RECORD,
   "video_gpu_record"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_GPU_SCREENSHOT,
   "video_gpu_screenshot"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_HARD_SYNC,
   "video_hard_sync"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_HARD_SYNC_FRAMES,
   "video_hard_sync_frames"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_MAX_SWAPCHAIN_IMAGES,
   "video_max_swapchain_images"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_WAITABLE_SWAPCHAINS,
   "video_waitable_swapchains"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_MAX_FRAME_LATENCY,
   "video_max_frame_latency"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_MESSAGE_POS_X,
   "video_message_pos_x"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_MESSAGE_POS_Y,
   "video_message_pos_y"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_MONITOR_INDEX,
   "video_monitor_index"
   )
#if defined(WIIU)
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_WIIU_PREFER_DRC,
   "video_wiiu_prefer_drc"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_WINDOW_OFFSET_X,
   "video_window_offset_x"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_WINDOW_OFFSET_Y,
   "video_window_offset_y"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_POST_FILTER_RECORD,
   "video_post_filter_record"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_REFRESH_RATE,
   "video_refresh_rate"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_REFRESH_RATE_AUTO,
   "video_refresh_rate_auto"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_REFRESH_RATE_POLLED,
   "video_refresh_rate_polled"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_AUTOSWITCH_REFRESH_RATE,
   "video_autoswitch_refresh_rate"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_AUTOSWITCH_PAL_THRESHOLD,
   "video_autoswitch_pal_threshold"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_ROTATION,
   "video_rotation"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SCREEN_ORIENTATION,
   "screen_orientation"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SCALE,
   "video_scale"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SCALE_INTEGER,
   "video_scale_integer"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SCALE_INTEGER_AXIS,
   "video_scale_integer_axis"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SCALE_INTEGER_SCALING,
   "video_scale_integer_scaling"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SETTINGS,
   "video_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_WINDOWED_MODE_SETTINGS,
   "video_windowed_mode_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_FULLSCREEN_MODE_SETTINGS,
   "video_fullscreen_mode_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SCALING_SETTINGS,
   "video_scaling_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_HDR_SETTINGS,
   "video_hdr_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SYNCHRONIZATION_SETTINGS,
   "video_synchronization_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_NOTCH_WRITE_OVER,
   "video_notch_write_over"
)
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_USE_METAL_ARG_BUFFERS,
   "video_use_metal_arg_buffers"
)
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_OUTPUT_SETTINGS,
   "video_output_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CRT_SWITCHRES_SETTINGS,
   "crt_switchres_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_DIR,
   "video_shader_dir"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SHADER_WATCH_FOR_CHANGES,
   "video_shader_watch_files"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_REMEMBER_LAST_DIR,
   "video_shader_remember_last_dir"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SHADER_APPLY_CHANGES,
   "shader_apply_changes"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SHADER_OPTIONS,
   "shader_options"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SHADER_PARAMETERS_ENTRY,
   "shader_parameters_entry"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_FILTER_PASS,
   "video_shader_filter_pass"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_NUM_PASSES,
   "video_shader_num_passes"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_PARAMETERS,
   "video_shader_parameters"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_PASS,
   "video_shader_pass"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_PRESET,
   "video_shader_preset"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_PREPEND,
   "video_shader_preset_prepend"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_APPEND,
   "video_shader_preset_append"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_PARAMETERS,
   "video_shader_preset_parameters"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_MANAGER,
   "video_shader_preset_manager"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_REMOVE_GLOBAL,
   "video_shader_preset_remove_global"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_REMOVE_CORE,
   "video_shader_preset_remove_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_REMOVE_PARENT,
   "video_shader_preset_remove_parent"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_REMOVE_GAME,
   "video_shader_preset_remove_game"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_SAVE_REFERENCE,
   "video_shader_preset_save_reference"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_SAVE_CURRENT,
   "video_shader_preset_save_current"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_SAVE_AS,
   "video_shader_preset_save_as"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_SAVE_GLOBAL,
   "video_shader_preset_save_global"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_SAVE_CORE,
   "video_shader_preset_save_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_SAVE_PARENT,
   "video_shader_preset_save_parent"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_SAVE_GAME,
   "video_shader_preset_save_game"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADER_SCALE_PASS,
   "video_shader_scale_pass"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHARED_CONTEXT,
   "video_shared_context"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SMOOTH,
   "video_smooth"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_CTX_SCALING,
   "video_ctx_scaling"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SOFT_FILTER,
   "soft_filter"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SWAP_INTERVAL,
   "video_swap_interval"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_TAB,
   "video_tab"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_THREADED,
   "video_threaded"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_VFILTER,
   "video_vfilter"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_VIEWPORT_CUSTOM_HEIGHT,
   "video_viewport_custom_height"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_VIEWPORT_CUSTOM_WIDTH,
   "video_viewport_custom_width"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_VIEWPORT_CUSTOM_X,
   "video_viewport_custom_x"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_VIEWPORT_CUSTOM_Y,
   "video_viewport_custom_y"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_VI_WIDTH,
   "video_vi_width"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_OVERSCAN_CORRECTION_TOP,
   "video_overscan_correction_top"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_OVERSCAN_CORRECTION_BOTTOM,
   "video_overscan_correction_bottom"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_VSYNC,
   "video_vsync"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_ADAPTIVE_VSYNC,
   "video_adaptive_vsync"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_WINDOWED_FULLSCREEN,
   "video_windowed_fullscreen"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_WINDOW_WIDTH,
   "video_window_width"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_WINDOW_HEIGHT,
   "video_window_height"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_WINDOW_AUTO_WIDTH_MAX,
   "video_window_auto_width_max"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_WINDOW_AUTO_HEIGHT_MAX,
   "video_window_auto_height_max"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_FULLSCREEN_X,
   "video_fullscreen_x"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_FULLSCREEN_Y,
   "video_fullscreen_y"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_FORCE_RESOLUTION,
   "video_force_resolution"
)
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_LAYOUT_ENABLE,
   "video_layout_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_LAYOUT_PATH,
   "video_layout_path"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_LAYOUT_SELECTED_VIEW,
   "video_layout_selected_view"
   )
MSG_HASH(
   MENU_ENUM_LABEL_WIFI_DRIVER,
   "wifi_driver"
   )
MSG_HASH(
   MENU_ENUM_LABEL_WIFI_SETTINGS,
   "wifi_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_BLUETOOTH_SETTINGS,
   "bluetooth_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_XMB_ALPHA_FACTOR,
   "xmb_alpha_factor"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_FONT_COLOR_RED,
   "menu_font_color_red"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_FONT_COLOR_GREEN,
   "menu_font_color_green"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_FONT_COLOR_BLUE,
   "menu_font_color_blue"
   )
MSG_HASH(
   MENU_ENUM_LABEL_XMB_FONT,
   "xmb_font"
   )
MSG_HASH(
   MENU_ENUM_LABEL_XMB_MAIN_MENU_ENABLE_SETTINGS,
   "xmb_main_menu_enable_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_XMB_MENU_COLOR_THEME,
   "xmb_menu_color_theme"
   )
MSG_HASH(
   MENU_ENUM_LABEL_XMB_RIBBON_ENABLE,
   "xmb_ribbon_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_XMB_SHADOWS_ENABLE,
   "xmb_shadows_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_SHOW_HISTORY,
   "content_show_history"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_SHOW_ADD_ENTRY,
   "content_show_add_entry"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_SHOW_PLAYLISTS,
   "content_show_playlists"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_SHOW_EXPLORE,
   "content_show_explore"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_SHOW_CONTENTLESS_CORES,
   "content_show_contentless_cores"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_SHOW_FAVORITES,
   "content_show_favorites"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_SHOW_FAVORITES_FIRST,
   "content_show_favorites_first"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_SHOW_IMAGES,
   "content_show_images"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_SHOW_MUSIC,
   "content_show_music"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_SHOW_SETTINGS,
   "content_show_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_SHOW_SETTINGS_PASSWORD,
   "content_show_settings_password"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_SHOW_VIDEO,
   "content_show_video"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_SHOW_NETPLAY,
   "content_show_netplay"
   )
MSG_HASH(
   MENU_ENUM_LABEL_XMB_LAYOUT,
   "xmb_layout"
   )
MSG_HASH(
   MENU_ENUM_LABEL_XMB_THEME,
   "xmb_theme"
   )
MSG_HASH(
   MSG_BRINGING_UP_COMMAND_INTERFACE_ON_PORT,
   "bringing_up_command_interface_at_port"
   )
MSG_HASH(
   MSG_CONNECT_DEVICE_FROM_A_VALID_PORT,
   "connect_device_from_a_valid_port"
   )
MSG_HASH(
   MSG_DEVICE_CONFIGURED_IN_PORT,
   "configured in port"
   )
MSG_HASH(
   MSG_DISCONNECTING_DEVICE_FROM_PORT,
   "disconnecting_device_from_port"
   )
MSG_HASH(
   MSG_DISCONNECT_DEVICE_FROM_A_VALID_PORT,
   "disconnect_device_from_a_valid_port"
   )
MSG_HASH(
   MSG_FAILED_TO_START_AUDIO_DRIVER,
   "failed_to_start_audio_driver"
   )
MSG_HASH(
   MSG_FOUND_LAST_STATE_SLOT,
   "found_last_state_slot"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DATABASE_SELECTION,
   "database_selection"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DATABASE_CURSOR_LIST,
   "database_cursor_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_DEVELOPER,
   "database_cursor_list_entry_developer"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_PUBLISHER,
   "database_cursor_list_entry_publisher"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OFF, "off"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ON,  "on"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DISABLED, "disabled"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ENABLED,  "enabled"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SECONDS,  "seconds"
   )
MSG_HASH(
   MENU_ENUM_LABEL_STATUS,   "status"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DETECT_CORE_LIST_OK,
   "detect_core_list_ok"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DETECT_CORE_LIST_OK_CURRENT_CORE,
   "detect_core_list_ok_current_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_DISK,
   "no_disk"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_RPL_ENTRY_ACTIONS,
   "deferred_rpl_entry_actions"
   )
MSG_HASH(
   MENU_ENUM_LABEL_OVERLAY_SETTINGS,
   "overlay_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_ORIGIN,
   "database_cursor_list_entry_origin"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_FRANCHISE,
   "database_cursor_list_entry_franchise"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_ESRB_RATING,
   "database_cursor_list_entry_esrb_rating"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_ELSPA_RATING,
   "database_cursor_list_entry_elspa_rating"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_PEGI_RATING,
   "database_cursor_list_entry_pegi_rating"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_CERO_RATING,
   "database_cursor_list_entry_cero_rating"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_BBFC_RATING,
   "database_cursor_list_entry_bbfc_rating"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_MAX_USERS,
   "database_cursor_list_entry_max_users"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_RELEASEDATE_BY_MONTH,
   "database_cursor_list_releasedate_by_month"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_RELEASEDATE_BY_YEAR,
   "database_cursor_list_releasedate_by_year"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_EDGE_MAGAZINE_ISSUE,
   "database_cursor_list_edge_magazine_issue"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_EDGE_MAGAZINE_RATING,
   "database_cursor_list_edge_magazine_rating"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_DATABASE_INFO,
   "database_info"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SHADER_PIPELINE_RIBBON,
   "shader_pipeline_ribbon"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SHADER_PIPELINE_RIBBON_SIMPLIFIED,
   "shader_pipeline_ribbon_simplified"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SHADER_PIPELINE_SIMPLE_SNOW,
   "shader_pipeline_simple_snow"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SHADER_PIPELINE_SNOW,
   "shader_pipeline_snow"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_UNIFIED_MENU_CONTROLS,
   "unified_menu_controls"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DISABLE_INFO_BUTTON,
   "disable_info_button"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DISABLE_SEARCH_BUTTON,
   "disable_search_button"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DISABLE_LEFT_ANALOG_IN_MENU,
   "disable_left_analog_in_menu"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DISABLE_RIGHT_ANALOG_IN_MENU,
   "disable_right_analog_in_menu"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUIT_PRESS_TWICE,
   "quit_press_twice"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FILE_DETECT_CORE_LIST_PUSH_DIR,
   "detect_core_list_push_dir"
   )
MSG_HASH(
   MENU_ENUM_LABEL_BATTERY_LEVEL_ENABLE,
   "menu_battery_level_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SHOW_SUBLABELS,
   "menu_show_sublabels"
   )
MSG_HASH(
   MENU_ENUM_LABEL_BROWSE_URL,
   "browse_url"
   )
MSG_HASH(
   MENU_ENUM_LABEL_BROWSE_START,
   "browse_start"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SHADER_PIPELINE_BOKEH,
   "shader_pipeline_bokeh"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_USE_MITM_SERVER,
   "netplay_use_mitm_server"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_MITM_SERVER,
   "netplay_mitm_server"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NETPLAY_CUSTOM_MITM_SERVER,
   "netplay_custom_mitm_server"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ADD_TO_MIXER,
   "audio_add_to_mixer"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ADD_TO_MIXER_AND_PLAY,
   "audio_add_to_mixer_and_play"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ADD_TO_MIXER_AND_COLLECTION,
   "audio_add_to_mixer_and_collection"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ADD_TO_MIXER_AND_COLLECTION_AND_PLAY,
   "audio_add_to_mixer_and_collection_and_play"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FILTER_BY_CURRENT_CORE,
   "filter_by_current_Core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_MIXER_VOLUME,
   "audio_mixer_volume"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_MIXER_MUTE,
   "audio_mixer_mute_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SHOW_ONLINE_UPDATER,
   "menu_show_online_updater"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SHOW_CORE_UPDATER,
   "menu_show_core_updater"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SHOW_LEGACY_THUMBNAIL_UPDATER,
   "menu_show_legacy_thumbnail_updater"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SCROLL_FAST,
   "menu_scroll_fast"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SCROLL_DELAY,
   "menu_scroll_delay"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_LOCK,
   "core_lock"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_SET_STANDALONE_EXEMPT,
   "core_set_standalone_exempt"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CORE_DELETE,
   "core_delete"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_ENTRY_RENAME,
   "playlist_entry_rename"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_FRAMEBUFFER_OPACITY,
   "menu_framebuffer_opacity"
   )
MSG_HASH(
   MENU_ENUM_LABEL_GOTO_FAVORITES,
   "goto_favorites"
   )
MSG_HASH(
   MENU_ENUM_LABEL_GOTO_MUSIC,
   "goto_music"
   )
MSG_HASH(
   MENU_ENUM_LABEL_GOTO_IMAGES,
   "goto_images"
   )
MSG_HASH(
   MENU_ENUM_LABEL_GOTO_VIDEO,
   "goto_video"
   )
MSG_HASH(
   MENU_ENUM_LABEL_GOTO_EXPLORE,
   "goto_explore"
   )
MSG_HASH(
   MENU_ENUM_LABEL_GOTO_CONTENTLESS_CORES,
   "goto_contentless_cores"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MATERIALUI_ICONS_ENABLE,
   "materialui_icons_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MATERIALUI_SWITCH_ICONS,
   "materialui_switch_icons"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MATERIALUI_PLAYLIST_ICONS_ENABLE,
   "materialui_playlist_icons_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MATERIALUI_LANDSCAPE_LAYOUT_OPTIMIZATION,
   "materialui_landscape_layout_optimization"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MATERIALUI_SHOW_NAV_BAR,
   "materialui_show_nav_bar"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MATERIALUI_AUTO_ROTATE_NAV_BAR,
   "materialui_auto_rotate_nav_bar"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MATERIALUI_DUAL_THUMBNAIL_LIST_VIEW_ENABLE,
   "materialui_dual_thumbnail_list_view_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MATERIALUI_THUMBNAIL_BACKGROUND_ENABLE,
   "materialui_thumbnail_background_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_THUMBNAIL_BACKGROUND_ENABLE,
   "menu_thumbnail_background_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RENAME_ENTRY,
   "rename_entry"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SHOW_LOAD_CORE,
   "menu_show_load_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SHOW_LOAD_CONTENT,
   "menu_show_load_content"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SHOW_LOAD_DISC,
   "menu_show_load_disc"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SHOW_DUMP_DISC,
   "menu_show_dump_disc"
   )
#ifdef HAVE_LAKKA
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SHOW_EJECT_DISC,
   "menu_show_eject_disc"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SHOW_INFORMATION,
   "menu_show_information"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SHOW_CONFIGURATIONS,
   "menu_show_configurations"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SHOW_HELP,
   "menu_show_help"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SHOW_QUIT_RETROARCH,
   "menu_show_quit_retroarch"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SHOW_RESTART_RETROARCH,
   "menu_show_restart_retroarch"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SHOW_REBOOT,
   "menu_show_reboot"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SHOW_SHUTDOWN,
   "menu_show_shutdown"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_START_RECORDING,
   "quick_menu_start_recording"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_START_STREAMING,
   "quick_menu_start_streaming"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_STOP_RECORDING,
   "quick_menu_stop_recording"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_STOP_STREAMING,
   "quick_menu_stop_streaming"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_TAKE_SCREENSHOT,
   "quick_menu_show_take_screenshot"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_SAVE_LOAD_STATE,
   "quick_menu_show_save_load_state"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_REPLAY,
   "quick_menu_show_replay"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_UNDO_SAVE_LOAD_STATE,
   "quick_menu_show_undo_save_load_state"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_ADD_TO_FAVORITES,
   "quick_menu_show_add_to_favorites"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_ADD_TO_PLAYLIST,
   "quick_menu_show_add_to_playlist"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_START_RECORDING,
   "quick_menu_show_start_recording"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_START_STREAMING,
   "quick_menu_show_start_streaming"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_SET_CORE_ASSOCIATION,
   "quick_menu_show_set_core_association"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_RESET_CORE_ASSOCIATION,
   "quick_menu_show_reset_core_association"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_SAVESTATE_SUBMENU,
   "quick_menu_show_savestate_submenu"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_OPTIONS,
   "quick_menu_show_options"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_CORE_OPTIONS_FLUSH,
   "quick_menu_show_core_options_flush"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_CONTROLS,
   "quick_menu_show_controls"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_CHEATS,
   "quick_menu_show_cheats"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_SHADERS,
   "quick_menu_show_shaders"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_SAVE_CORE_OVERRIDES,
   "quick_menu_show_save_core_overrides"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_SAVE_CONTENT_DIR_OVERRIDES,
   "quick_menu_show_save_content_dir_overrides"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_SAVE_GAME_OVERRIDES,
   "quick_menu_show_save_game_overrides"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_INFORMATION,
   "quick_menu_show_information"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_DOWNLOAD_THUMBNAILS,
   "quick_menu_show_download_thumbnails"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_ENABLE_KIOSK_MODE,
   "menu_enable_kiosk_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_DISABLE_KIOSK_MODE,
   "menu_disable_kiosk_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_KIOSK_MODE_PASSWORD,
   "menu_disable_kiosk_mode_password"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_MESSAGE_BGCOLOR_ENABLE,
   "video_msg_bgcolor_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_MESSAGE_BGCOLOR_RED,
   "video_msg_bgcolor_red"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_MESSAGE_BGCOLOR_GREEN,
   "video_msg_bgcolor_green"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_MESSAGE_BGCOLOR_BLUE,
   "video_msg_bgcolor_blue"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_MESSAGE_BGCOLOR_OPACITY,
   "video_msg_bgcolor_opacity"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_MESSAGE_COLOR_RED,
   "video_msg_color_red"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_MESSAGE_COLOR_GREEN,
   "video_msg_color_green"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_MESSAGE_COLOR_BLUE,
   "video_msg_color_blue"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FRAMECOUNT_SHOW,
   "framecount_show"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MEMORY_SHOW,
   "memory_show"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_WINDOW_OPACITY,
   "video_window_opacity"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_RESAMPLER_QUALITY,
   "audio_resampler_quality"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_RESAMPLER_DRIVER_SINC,
   "sinc"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_RESAMPLER_DRIVER_CC,
   "CC"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_RESAMPLER_DRIVER_NEAREST,
   "nearest"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_RESAMPLER_DRIVER_NULL,
   "null"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_ANDROID,
   "android"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_PS4,
   "ps4"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_PS3,
   "ps3"
   )
#ifdef VITA
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_PSP,
   "vita"
   )
#else
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_PSP,
   "psp"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_PS2,
   "ps2"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_CTR,
   "ctr"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_SWITCH,
   "switch"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_SDL,
   "sdl"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_SDL2,
   "sdl2"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_SDL_DINGUX,
   "sdl_dingux"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_DINPUT,
   "dinput"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_WINRAW,
   "raw"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_X,
   "x"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_WAYLAND,
   "wayland"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_XENON360,
   "xenon360"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_XINPUT,
   "xinput"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_UWP,
   "uwp"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_WII,
   "gx"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_WIIU,
   "wiiu"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_UDEV,
   "udev"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_LINUXRAW,
   "linuxraw"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_COCOA,
   "cocoa"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_QNX,
   "qnx_input"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_RWEBINPUT,
   "rwebinput"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_DOS,
   "dos"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_DRIVER_NULL,
   "null"
)
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_ANDROID,
   "android"
)
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_CTR,
   "ctr"
)
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_DINPUT,
   "dinput"
)
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_DOS,
   "dos"
)
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_GX,
   "gx"
)
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_HID,
   "hid"
)
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_LINUXRAW,
   "linuxraw"
)
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_PARPORT,
   "parport"
)
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_PS2,
   "ps2"
)
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_PS3,
   "ps3"
)
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_PS4,
   "ps4"
)
#ifdef VITA
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_PSP,
   "vita"
)
#else
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_PSP,
   "psp"
)
#endif
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_QNX,
   "qnx"
)
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_RWEBPAD,
   "rwebpad"
)
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_SDL_DINGUX,
   "sdl_dingux"
)
#ifdef HAVE_SDL2
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_SDL,
   "sdl2"
)
#else
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_SDL,
   "sdl"
)
#endif
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_SWITCH,
   "switch"
)
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_UDEV,
   "udev"
)
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_WIIU,
   "wiiu"
)
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_XDK,
   "xdk"
)
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_XINPUT,
   "xinput"
)
MSG_HASH(
   MENU_ENUM_LABEL_JOYPAD_DRIVER_NULL,
   "null"
)

MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_WINDOW_SHOW_DECORATIONS,
   "video_window_show_decorations"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_WINDOW_SAVE_POSITION,
   "video_window_save_position"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_WINDOW_CUSTOM_SIZE_ENABLE,
   "video_window_custom_size_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_RGUI_BORDER_FILLER_ENABLE,
   "menu_rgui_border_filler_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_RGUI_BORDER_FILLER_THICKNESS_ENABLE,
   "menu_rgui_border_filler_thickness_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_RGUI_BACKGROUND_FILLER_THICKNESS_ENABLE,
   "menu_rgui_background_filler_thickness_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_RGUI_INTERNAL_UPSCALE_LEVEL,
   "rgui_internal_upscale_level"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_RGUI_ASPECT_RATIO,
   "rgui_aspect_ratio"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_RGUI_ASPECT_RATIO_LOCK,
   "rgui_aspect_ratio_lock"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_RGUI_FULL_WIDTH_LAYOUT,
   "menu_rgui_full_width_layout"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_RGUI_TRANSPARENCY,
   "menu_rgui_transparency"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_RGUI_SHADOWS,
   "menu_rgui_shadows"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_RGUI_PARTICLE_EFFECT,
   "rgui_particle_effect"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_RGUI_PARTICLE_EFFECT_SPEED,
   "rgui_particle_effect_speed"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_RGUI_PARTICLE_EFFECT_SCREENSAVER,
   "rgui_particle_effect_screensaver"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_RGUI_EXTENDED_ASCII,
   "rgui_extended_ascii"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_RGUI_SWITCH_ICONS,
   "rgui_switch_icons"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_SHOW_REWIND,
   "menu_show_rewind_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_SHOW_LATENCY,
   "menu_show_latency_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_SHOW_OVERLAYS,
   "menu_show_overlay_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_SHOW_VIDEO_LAYOUT,
   "menu_show_video_layout_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_ENABLE_MENU,
   "audio_enable_menu"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AUDIO_MIXER_SETTINGS,
   "audio_mixer_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SOUNDS,
   "menu_sounds"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_MIXER_STREAM_SETTINGS_LIST,
   "deferred_mixer_stream_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_OVERRIDE_OPTIONS,
   "quick_menu_override_options"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_QUICK_MENU_OVERRIDE_OPTIONS,
   "deferred_quick_menu_override_options"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DISCORD_IN_MENU,
   "discord_in_menu"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DISCORD_IN_GAME,
   "discord_in_game"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DISCORD_IN_GAME_PAUSED,
   "discord_in_game_paused"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DISCORD_STATUS_PLAYING,
   "discord_status_playing"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DISCORD_STATUS_PAUSED,
   "discord_status_paused"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MIDI_INPUT,
   "midi_input"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MIDI_OUTPUT,
   "midi_output"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MIDI_VOLUME,
   "midi_volume"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SUSTAINED_PERFORMANCE_MODE,
   "sustained_performance_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_IDX,
   "cheat_idx"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_DESC,
   "cheat_desc"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_STATE,
   "cheat_state"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_CODE,
   "cheat_code"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_HANDLER,
   "cheat_handler"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_MEMORY_SEARCH_SIZE,
   "cheat_memory_search_size"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_TYPE,
   "cheat_type"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_VALUE,
   "cheat_value"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_REPEAT_COUNT,
   "cheat_repeat_count"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_REPEAT_ADD_TO_VALUE,
   "cheat_repeat_add_to_value"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_REPEAT_ADD_TO_ADDRESS,
   "cheat_repeat_add_to_address"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_ADDRESS,
   "cheat_address"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_ADDRESS_BIT_POSITION,
   "cheat_address_bit_position"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_RUMBLE_TYPE,
   "cheat_rumble_type"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_RUMBLE_VALUE,
   "cheat_rumble_value"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_RUMBLE_PORT,
   "cheat_rumble_port"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_RUMBLE_PRIMARY_STRENGTH,
   "cheat_rumble_primary_strength"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_RUMBLE_PRIMARY_DURATION,
   "cheat_rumble_primary_duration"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_RUMBLE_SECONDARY_STRENGTH,
   "cheat_rumble_secondary_strength"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_RUMBLE_SECONDARY_DURATION,
   "cheat_rumble_secondary_duration"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_ADD_NEW_AFTER,
   "cheat_add_new_after"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_ADD_NEW_BEFORE,
   "cheat_add_new_before"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_COPY_AFTER,
   "cheat_copy_after"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_COPY_BEFORE,
   "cheat_copy_before"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_DELETE,
   "cheat_delete"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_START_OR_CONT,
   "cheat_start_or_cont"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_START_OR_RESTART,
   "cheat_start_or_restart"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_SEARCH_EXACT,
   "cheat_search_exact"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_SEARCH_LT,
   "cheat_search_lt"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_SEARCH_GT,
   "cheat_search_gt"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_SEARCH_LTE,
   "cheat_search_lte"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_SEARCH_GTE,
   "cheat_search_gte"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_SEARCH_EQ,
   "cheat_search_eq"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_SEARCH_NEQ,
   "cheat_search_neq"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_SEARCH_EQPLUS,
   "cheat_search_eqplus"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_SEARCH_EQMINUS,
   "cheat_search_eqminus"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_ADD_MATCHES,
   "cheat_add_matches"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_VIEW_MATCHES,
   "cheat_view_matches"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_CREATE_OPTION,
   "cheat_create_option"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_DELETE_OPTION,
   "cheat_delete_option"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_ADD_NEW_TOP,
   "cheat_add_new_top"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_ADD_NEW_BOTTOM,
   "cheat_add_new_bottom"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_DELETE_ALL,
   "cheat_delete_all"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_RELOAD_CHEATS,
   "cheat_reload_cheats"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_BIG_ENDIAN,
   "cheat_big_endian"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_MATCH_IDX,
   "cheat_match_idx"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_MATCH,
   "cheat_match"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_BROWSE_MEMORY,
   "cheat_browse_memory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_COPY_MATCH,
   "cheat_copy_match"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CHEAT_DELETE_MATCH,
   "cheat_delete_match"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CRT_SWITCH_HIRES_MENU,
   "crt_switch_hires_menu"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CRT_SWITCH_RESOLUTION_USE_CUSTOM_REFRESH_RATE,
   "crt_switch_resolution_use_custom_refresh_rate"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CRT_SWITCH_RESOLUTION_OUTPUT_DISPLAY_ID,
   "crt_switch_resolution_output_display_id"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_RECORD_QUALITY,
   "video_record_quality"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_STREAM_QUALITY,
   "video_stream_quality"
   )
MSG_HASH(
   MENU_ENUM_LABEL_STREAMING_URL,
   "streaming_url"
   )
MSG_HASH(
   MENU_ENUM_LABEL_UDP_STREAM_PORT,
   "udp_stream_port"
   )
MSG_HASH(
   MENU_ENUM_LABEL_TWITCH_STREAM_KEY,
   "twitch_stream_key"
   )
MSG_HASH(
   MENU_ENUM_LABEL_YOUTUBE_STREAM_KEY,
   "youtube_stream_key"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FACEBOOK_STREAM_KEY,
   "facebook_stream_key"
   )
MSG_HASH(
   MENU_ENUM_LABEL_STREAMING_MODE,
   "streaming_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_STREAMING_TITLE,
   "streaming_title"
   )
MSG_HASH(
   MENU_ENUM_LABEL_RESET_TO_DEFAULT_CONFIG,
   "reset_to_default_config"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_USE_PREFERRED_SYSTEM_COLOR_THEME,
   "menu_use_preferred_system_color_theme"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_MUSIC_AVAILABLE,
   "no_music"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_VIDEOS_AVAILABLE,
   "no_videos"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_IMAGES_AVAILABLE,
   "no_images"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NO_FAVORITES_AVAILABLE,
   "no_favorites"
   )
#ifdef _3DS
MSG_HASH(
   MENU_ENUM_LABEL_NEW3DS_SPEEDUP_ENABLE,
   "new3ds_speedup_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_3DS_LCD_BOTTOM,
   "video_3ds_lcd_bottom"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_3DS_DISPLAY_MODE,
   "video_3ds_display_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_BOTTOM_ASSETS_DIRECTORY,
   "bottom_assets_directory"
   )
MSG_HASH(
   MENU_ENUM_LABEL_BOTTOM_FONT_ENABLE,
   "bottom_font_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_BOTTOM_FONT_COLOR_RED,
   "bottom_font_color_red"
   )
MSG_HASH(
   MENU_ENUM_LABEL_BOTTOM_FONT_COLOR_GREEN,
   "bottom_font_color_green"
   )
MSG_HASH(
   MENU_ENUM_LABEL_BOTTOM_FONT_COLOR_BLUE,
   "bottom_font_color_blue"
   )
MSG_HASH(
   MENU_ENUM_LABEL_BOTTOM_FONT_COLOR_OPACITY,
   "bottom_font_color_opacity"
   )
MSG_HASH(
   MENU_ENUM_LABEL_BOTTOM_FONT_SCALE,
   "bottom_font_scale"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_USE_OLD_FORMAT,
   "playlist_use_old_format"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_COMPRESSION,
   "playlist_compression"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SOUND_OK,
   "menu_sound_ok"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SOUND_CANCEL,
   "menu_sound_cancel"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SOUND_NOTICE,
   "menu_sound_notice"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SOUND_BGM,
   "menu_sound_bgm"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SOUND_SCROLL,
   "menu_sound_scroll"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_RUNTIME_LOG,
   "content_runtime_log"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CONTENT_RUNTIME_LOG_AGGREGATE,
   "content_runtime_log_aggregate"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_SHOW_INLINE_CORE_NAME,
   "playlist_show_inline_core_name"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_SORT_ALPHABETICAL,
   "playlist_sort_alphabetical"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_SHOW_SUBLABELS,
   "playlist_show_sublabels"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_SHOW_HISTORY_ICONS,
   "playlist_show_history_icons"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_SHOW_ENTRY_IDX,
   "playlist_show_entry_idx"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_FUZZY_ARCHIVE_MATCH,
   "playlist_fuzzy_archive_match"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_SUBLABEL_RUNTIME_TYPE,
   "playlist_sublabel_runtime_type"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_SUBLABEL_LAST_PLAYED_STYLE,
   "playlist_sublabel_last_played_style"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_PORTABLE_PATHS,
   "playlist_portable_paths"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_USE_FILENAME,
   "playlist_use_filename"
   )
MSG_HASH(
   MENU_ENUM_LABEL_PLAYLIST_ALLOW_NON_PNG,
   "playlist_allow_non_png"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIBRATE_ON_KEYPRESS,
   "vibrate_on_keypress"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ENABLE_DEVICE_VIBRATION,
   "enable_device_vibration"
   )
MSG_HASH(
   MENU_ENUM_LABEL_LOG_DIR,
   "log_dir"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_WIDGETS_ENABLE,
   "menu_widgets_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_SHOW_LOAD_CONTENT_ANIMATION,
   "menu_show_load_content_animation"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NOTIFICATION_SHOW_AUTOCONFIG,
   "notification_show_autoconfig"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NOTIFICATION_SHOW_AUTOCONFIG_FAILS,
   "notification_show_autoconfig_fails"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NOTIFICATION_SHOW_CHEATS_APPLIED,
   "notification_show_cheats_applied"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NOTIFICATION_SHOW_PATCH_APPLIED,
   "notification_show_patch_applied"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NOTIFICATION_SHOW_REMAP_LOAD,
   "notification_show_remap_load"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NOTIFICATION_SHOW_CONFIG_OVERRIDE_LOAD,
   "notification_show_config_override_load"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NOTIFICATION_SHOW_SET_INITIAL_DISK,
   "notification_show_set_initial_disk"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NOTIFICATION_SHOW_DISK_CONTROL,
   "notification_show_disk_control"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NOTIFICATION_SHOW_SAVE_STATE,
   "notification_show_save_state"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NOTIFICATION_SHOW_FAST_FORWARD,
   "notification_show_fast_forward"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NOTIFICATION_SHOW_SCREENSHOT,
   "notification_show_screenshot"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NOTIFICATION_SHOW_SCREENSHOT_DURATION,
   "notification_show_screenshot_duration"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NOTIFICATION_SHOW_SCREENSHOT_FLASH,
   "notification_show_screenshot_flash"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NOTIFICATION_SHOW_REFRESH_RATE,
   "notification_show_refresh_rate"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NOTIFICATION_SHOW_NETPLAY_EXTRA,
   "notification_show_netplay_extra"
   )
MSG_HASH(
   MENU_ENUM_LABEL_NOTIFICATION_SHOW_WHEN_MENU_IS_ALIVE,
   "notification_show_when_menu_is_alive"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_SHADERS_ENABLE,
   "video_shader_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SCAN_WITHOUT_CORE_MATCH,
   "scan_without_core_match"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SCAN_SERIAL_AND_CRC,
   "scan_serial_and_crc"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_XMB_ANIMATION_HORIZONTAL_HIGHLIGHT,
   "xmb_menu_animation_horizontal_highlight"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_XMB_ANIMATION_MOVE_UP_DOWN,
   "xmb_menu_animation_move_up_down"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_XMB_ANIMATION_OPENING_MAIN_MENU,
   "xmb_menu_animation_opening_main_menu"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_RECORD_THREADS,
   "video_record_threads"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VIDEO_GPU_INDEX,
   "gpu_index"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FPS_UPDATE_INTERVAL,
   "fps_update_interval"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MEMORY_UPDATE_INTERVAL,
   "memory_update_interval"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_RESUME_CONTENT,
   "quick_menu_show_resume_content"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_RESTART_CONTENT,
   "quick_menu_show_restart_content"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_CLOSE_CONTENT,
   "quick_menu_show_close_content"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_INPUT,
   "settings_show_input"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ACCESSIBILITY_SETTINGS,
   "accessibility_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_POWER_MANAGEMENT_SETTINGS,
   "power_management_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_CPU_PERFPOWER,
   "cpu_perfpower_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AI_SERVICE_SETTINGS,
   "ai_service_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AI_SERVICE_MODE,
   "ai_service_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AI_SERVICE_URL,
   "ai_service_url"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AI_SERVICE_ENABLE,
   "ai_service_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AI_SERVICE_TARGET_LANG,
   "ai_service_target_lang"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AI_SERVICE_SOURCE_LANG,
   "ai_service_source_lang"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_DRIVERS,
   "settings_show_drivers"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_VIDEO,
   "settings_show_video"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_AUDIO,
   "settings_show_audio"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_LATENCY,
   "settings_show_latency"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_CORE,
   "settings_show_core"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_CONFIGURATION,
   "settings_show_configuration"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_SAVING,
   "settings_show_saving"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_LOGGING,
   "settings_show_logging"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_FILE_BROWSER,
   "settings_show_file_browser"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_FRAME_THROTTLE,
   "settings_show_frame_throttle"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_RECORDING,
   "settings_show_recording"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_ONSCREEN_DISPLAY,
   "settings_show_onscreen_display"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_USER_INTERFACE,
   "settings_show_user_interface"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_AI_SERVICE,
   "settings_show_ai_service"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_ACCESSIBILITY,
   "settings_show_accessibility"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_POWER_MANAGEMENT,
   "settings_show_power_management"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_ACHIEVEMENTS,
   "settings_show_achievements"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_NETWORK,
   "settings_show_network"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_PLAYLISTS,
   "settings_show_playlists"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_USER,
   "settings_show_user"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_DIRECTORY,
   "settings_show_directory"
   )
#ifdef HAVE_MIST
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_SHOW_STEAM,
   "settings_show_steam"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_FRAME_TIME_COUNTER_RESET_AFTER_FASTFORWARDING,
   "frame_time_counter_reset_after_fastforwarding"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FRAME_TIME_COUNTER_RESET_AFTER_LOAD_STATE,
   "frame_time_counter_reset_after_load_state"
   )
MSG_HASH(
   MENU_ENUM_LABEL_FRAME_TIME_COUNTER_RESET_AFTER_SAVE_STATE,
   "frame_time_counter_reset_after_save_state"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DELETE_PLAYLIST,
   "delete_playlist"
   )
#ifdef HAVE_LAKKA
MSG_HASH(
   MENU_ENUM_LABEL_LOCALAP_ENABLE,
   "localap_enable"
   )
#endif
MSG_HASH(
   MENU_ENUM_LABEL_DRIVER_SWITCH_ENABLE,
   "driver_switch_enable"
   )
MSG_HASH(
   MENU_ENUM_LABEL_AI_SERVICE_PAUSE,
   "ai_service_pause"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_MANUAL_CONTENT_SCAN_LIST,
   "deferred_manual_content_scan_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MANUAL_CONTENT_SCAN_LIST,
   "manual_content_scan_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MANUAL_CONTENT_SCAN_DIR,
   "manual_content_scan_dir"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MANUAL_CONTENT_SCAN_SYSTEM_NAME,
   "manual_content_scan_system_name"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_MANUAL_CONTENT_SCAN_SYSTEM_NAME,
   "deferred_dropdown_box_list_manual_content_scan_system_name"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MANUAL_CONTENT_SCAN_SYSTEM_NAME_CUSTOM,
   "manual_content_scan_system_name_custom"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MANUAL_CONTENT_SCAN_CORE_NAME,
   "manual_content_scan_core_name"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_DROPDOWN_BOX_LIST_MANUAL_CONTENT_SCAN_CORE_NAME,
   "deferred_dropdown_box_list_manual_content_scan_core_name"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MANUAL_CONTENT_SCAN_FILE_EXTS,
   "manual_content_scan_file_exts"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MANUAL_CONTENT_SCAN_SEARCH_RECURSIVELY,
   "manual_content_scan_search_recursively"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MANUAL_CONTENT_SCAN_SEARCH_ARCHIVES,
   "manual_content_scan_search_archives"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MANUAL_CONTENT_SCAN_DAT_FILE,
   "manual_content_scan_dat_file"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MANUAL_CONTENT_SCAN_DAT_FILE_FILTER,
   "manual_content_scan_dat_file_filter"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MANUAL_CONTENT_SCAN_OVERWRITE,
   "manual_content_scan_overwrite"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MANUAL_CONTENT_SCAN_VALIDATE_ENTRIES,
   "manual_content_scan_validate_entries"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MANUAL_CONTENT_SCAN_START,
   "manual_content_scan_start"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ACCESSIBILITY_ENABLED,
   "accessibility_enabled"
   )
MSG_HASH(
   MENU_ENUM_LABEL_ACCESSIBILITY_NARRATOR_SPEECH_SPEED,
   "accessibility_narrator_speech_speed"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_AUDIO_OUTPUT_SETTINGS_LIST,
   "deferred_audio_output_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_DEFERRED_AUDIO_SYNCHRONIZATION_SETTINGS_LIST,
   "deferred_audio_synchronization_settings_list"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_MENU_SETTINGS,
   "input_menu_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_TURBO_FIRE_SETTINGS,
   "input_turbo_fire_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_HAPTIC_FEEDBACK_SETTINGS,
   "input_haptic_feedback_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_RUMBLE_GAIN,
   "input_rumble_gain"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_TURBO_MODE,
   "input_turbo_mode"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_TURBO_BIND,
   "input_turbo_bind"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_TURBO_BUTTON,
   "input_turbo_button"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_TURBO_PERIOD,
   "input_turbo_period"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_TURBO_DUTY_CYCLE,
   "input_turbo_duty_cycle"
   )
MSG_HASH(
   MENU_ENUM_LABEL_INPUT_TURBO_ALLOW_DPAD,
   "input_turbo_allow_dpad"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MENU_VIEWS_SETTINGS,
   "menu_views_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_VIEWS_SETTINGS,
   "quick_menu_views_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_SETTINGS_VIEWS_SETTINGS,
   "settings_views_settings"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MIXER_ACTION_PLAY,
   "mixer_action_play"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MIXER_ACTION_PLAY_LOOPED,
   "mixer_action_play_looped"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MIXER_ACTION_PLAY_SEQUENTIAL,
   "mixer_action_play_sequential"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MIXER_ACTION_STOP,
   "mixer_action_stop"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MIXER_ACTION_REMOVE,
   "mixer_action_remove"
   )
MSG_HASH(
   MENU_ENUM_LABEL_MIXER_ACTION_VOLUME,
   "mixer_action_volume"
   )
MSG_HASH(
   MENU_ENUM_LABEL_GAMEMODE_ENABLE,
   "game_mode_enable"
   )
#ifdef HAVE_GAME_AI
MSG_HASH(
   MENU_ENUM_LABEL_CORE_GAME_AI_OPTIONS,
   "core_game_ai_options"
   )
MSG_HASH(
   MENU_ENUM_LABEL_QUICK_MENU_SHOW_GAME_AI,
   "quick_menu_show_game_ai"
   )
MSG_HASH(
   MENU_ENUM_LABEL_GAME_AI_OVERRIDE_P1,
   "game_ai_override_p1"
   )
MSG_HASH(
   MENU_ENUM_LABEL_GAME_AI_OVERRIDE_P2,
   "game_ai_override_p2"
   )
MSG_HASH(
   MENU_ENUM_LABEL_GAME_AI_SHOW_DEBUG,
   "game_ai_show_debug"
   )
#endif
